/*= R&S ESCI EMI Test Receiver Include File =================================*/

/*===========================================================================*/
/*  Please do not use global variables or arrays in the include file of      */
/*  instrument drivers that will be submitted for inclusion into the         */
/*  LabWindows Instrument Driver Library.                                    */
/*===========================================================================*/
     
#ifndef __RSESCI_HEADER
#define __RSESCI_HEADER

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

/*****************************************************************************/
/*= RSIB interface support ==================================================*/
/*                                                                           */
/* The RSIB interface is a R&S defined protocol for remote control of R&S    */
/* spectrum and network analyzers. In addition to the standard VISA          */
/* attributes, the RSIB passport supports the following manufacturer specific*/
/* attributes:                                                               */
/*                                                                           */
/*****************************************************************************/
#ifndef __RSVIRSIB_H__

#define RS_ATTR_RSIB_SRE     (0x3FFC0001UL)     /* Switch a device to local or remote */
#define RS_ATTR_RSIB_LOC     (0x3FFC0002UL)     /* Switch a device temporarily to local */
#define RS_ATTR_RSIB_VER     (0x3FFC0003UL)     /* Passport Release Version */

#endif /* __RSVIRSIB_H__ */

/*****************************************************************************/
/*= Instrument Driver Specific Error/Warning Codes ==========================*/
/*****************************************************************************/
#define VI_ERROR_INSTR_FILE_OPEN                (_VI_ERROR+0x3FFC0800L)
#define VI_ERROR_INSTR_FILE_WRITE               (_VI_ERROR+0x3FFC0801L)
#define VI_ERROR_INSTR_INTERPRETING_RESPONSE    (_VI_ERROR+0x3FFC0803L)
#define VI_ERROR_INSTR_PARAMETER9               (_VI_ERROR+0x3FFC0809L)
#define VI_ERROR_INSTR_PARAMETER10              (_VI_ERROR+0x3FFC080AL)
#define VI_ERROR_INSTR_PARAMETER11              (_VI_ERROR+0x3FFC080BL)
#define VI_ERROR_INSTR_PARAMETER12              (_VI_ERROR+0x3FFC080CL)
#define VI_ERROR_INSTR_PARAMETER13              (_VI_ERROR+0x3FFC080DL)
#define VI_ERROR_INSTR_PARAMETER14              (_VI_ERROR+0x3FFC080EL)
#define VI_ERROR_INSTR_PARAMETER15              (_VI_ERROR+0x3FFC080FL)
#define VI_ERROR_INSTR_PARAMETER16              (_VI_ERROR+0x3FFC0810L)	

/*****************************************************************************/
/*= Define Instrument Specific Error/Warning Codes Here =====================*/
/*****************************************************************************/
#define VI_WARNING_INSTR_OFFSET                     (0x3FFC0900L)
#define VI_ERROR_INSTR_OFFSET                       (_VI_ERROR+0x3FFC0900L)

#define RSESCI_ERROR_INSTRUMENT_ERROR               (VI_ERROR_INSTR_OFFSET + 0xF0L)
#define RSESCI_ERROR_INVALID_CONFIGURATION          (VI_ERROR_INSTR_OFFSET + 0xF1L)
#define RSESCI_ERROR_INSTRUMENT_OPTION              (VI_ERROR_INSTR_OFFSET + 0xF2L)
#define RSESCI_ERROR_INSTRUMENT_DATA_NOT_AVAILABLE  (VI_ERROR_INSTR_OFFSET + 0xF3L)
#define RSESCI_ERROR_SETTINGS_CONFLICT              (VI_ERROR_INSTR_OFFSET + 0xF4L)
#define RSESCI_WARNING_SMALL_BUFFER                 (VI_WARNING_INSTR_OFFSET + 0xF5L)
#define RSESCI_ERROR_INSTRUMENT_NSUP_MODEL          (VI_ERROR_INSTR_OFFSET + 0xF6L)
#define RSESCI_ERROR_INSTRUMENT_IQ_OVERLOAD         (VI_ERROR_INSTR_OFFSET + 0xF7L)

#define VI_WARN_NSUP_ID_QUERY     (          0x3FFC0101L)
#define VI_WARN_NSUP_RESET        (          0x3FFC0102L)
#define VI_WARN_NSUP_SELF_TEST    (          0x3FFC0103L)
#define VI_WARN_NSUP_ERROR_QUERY  (          0x3FFC0104L)
#define VI_WARN_NSUP_REV_QUERY    (          0x3FFC0105L)

#define VI_ERROR_PARAMETER1       (_VI_ERROR+0x3FFC0001L)
#define VI_ERROR_PARAMETER2       (_VI_ERROR+0x3FFC0002L)
#define VI_ERROR_PARAMETER3       (_VI_ERROR+0x3FFC0003L)
#define VI_ERROR_PARAMETER4       (_VI_ERROR+0x3FFC0004L)
#define VI_ERROR_PARAMETER5       (_VI_ERROR+0x3FFC0005L)
#define VI_ERROR_PARAMETER6       (_VI_ERROR+0x3FFC0006L)
#define VI_ERROR_PARAMETER7       (_VI_ERROR+0x3FFC0007L)
#define VI_ERROR_PARAMETER8       (_VI_ERROR+0x3FFC0008L)
#define VI_ERROR_FAIL_ID_QUERY    (_VI_ERROR+0x3FFC0011L)
#define VI_ERROR_INV_RESPONSE     (_VI_ERROR+0x3FFC0012L)


/*- Additional Definitions --------------------------------------------------*/

#define VI_ON                     (1)
#define VI_OFF                    (0)
/*****************************************************************************/
/*= Instrument specific defines =============================================*/
/*****************************************************************************/

/* --- Window -------------------------------------------------------------- */
#define RSESCI_SCREEN_A                     1
#define RSESCI_SCREEN_B                     2

/* --- Step Link ----------------------------------------------------------- */
#define RSESCI_FREQ_STEP_LINK_OFF           0
#define RSESCI_FREQ_STEP_LINK_RBW           1
#define RSESCI_FREQ_STEP_LINK_SPAN          2

/* --- Frequency Mode ------------------------------------------------------ */
#define RSESCI_FREQ_FIXED                   0
#define RSESCI_FREQ_SWEEP                   1
#define RSESCI_FREQ_SCAN                    2
#define RSESCI_FREQ_TDOM                    3

/* --- Axis Range Spacing -------------------------------------------------- */
#define RSESCI_SPACING_LIN                  0
#define RSESCI_SPACING_LOG                  1
#define RSESCI_SPACING_LDB                  2

/* --- Level Axis Unit ----------------------------------------------------- */
#define RSESCI_UNIT_DBM                     0
#define RSESCI_UNIT_VOLT                    1
#define RSESCI_UNIT_AMP                     2
#define RSESCI_UNIT_WATT                    3
#define RSESCI_UNIT_DBPW                    4
#define RSESCI_UNIT_DBUV                    5
#define RSESCI_UNIT_DBMV                    6
#define RSESCI_UNIT_DBUA                    7
#define RSESCI_UNIT_DBPT                    8
#define RSESCI_UNIT_DBUV_M                  9
#define RSESCI_UNIT_DBUA_M                  10
#define RSESCI_UNIT_DB                      11
#define RSESCI_UNIT_DBMV_M                  12
#define RSESCI_UNIT_DEG                     13
#define RSESCI_UNIT_RAD                     14
#define RSESCI_UNIT_S                       15
#define RSESCI_UNIT_HZ                      16
#define RSESCI_UNIT_PCT                     17
#define RSESCI_UNIT_DBUV_MHZ                18
#define RSESCI_UNIT_DBMV_MHZ                19
#define RSESCI_UNIT_DBUA_MHZ                20
#define RSESCI_UNIT_DBPW_MHZ                21
#define RSESCI_UNIT_DBPT_MHZ                22
#define RSESCI_UNIT_DBUV_MMHZ               23
#define RSESCI_UNIT_DBUA_MMHZ               24
#define RSESCI_UNIT_UNITLESS                25

/* --- Level Axis Scaling -------------------------------------------------- */
#define RSESCI_ABS                          0
#define RSESCI_REL                          1

/* --- RF Input Coupling --------------------------------------------------- */
#define RSESCI_COUPLING_AC                  0
#define RSESCI_COUPLING_DC                  1

/* --- RF Input Impedance -------------------------------------------------- */
#define RSESCI_INPUT_IMP_50                 0
#define RSESCI_INPUT_IMP_75                 1

/* --- Filter Type --------------------------------------------------------- */
#define RSESCI_FILTER_NORMAL                0
#define RSESCI_FILTER_FFT                   1
#define RSESCI_FILTER_CFIL                  2
#define RSESCI_FILTER_RRC                   3
#define RSESCI_FILTER_NOISE                 4
#define RSESCI_FILTER_PULSE                 5
#define RSESCI_FILTER_MIL                   6

/* --- Sweep Spacing ------------------------------------------------------- */
#define RSESCI_LIN                          0
#define RSESCI_LOG                          1
#define RSESCI_AUTO                         2
#define RSESCI_APUL                         3
#define RSESCI_ACW                          4	

/* --- Trigger Source ------------------------------------------------------ */
#define RSESCI_TRIG_IMM                     0
#define RSESCI_TRIG_EXT                     1
#define RSESCI_TRIG_VID                     2
#define RSESCI_TRIG_IFP                     3
#define RSESCI_TRIG_RFP                     4
#define RSESCI_TRIG_TV                      5
#define RSESCI_TRIG_FM                      6
#define RSESCI_TRIG_AM                      7
#define RSESCI_TRIG_PM                      8
#define RSESCI_TRIG_AF                      9
#define RSESCI_TRIG_AM_REL                  10	

/* --- Trigger Mode -------------------------------------------------------- */
#define RSESCI_TRIG_LEVEL                   0
#define RSESCI_TRIG_EDGE                    1

/* --- Trigger Polarity ---------------------------------------------------- */
#define RSESCI_POS                          0
#define RSESCI_NEG                          1

/* --- Field --------------------------------------------------------------- */
#define RSESCI_TVFIELD_ALL                  0
#define RSESCI_TVFIELD_ODD                  1
#define RSESCI_TVFIELD_EVEN                 2

/* --- CCVS Signal --------------------------------------------------------- */
#define RSESCI_INT                          0
#define RSESCI_EXT                          1
/*Fail-safe External*/	
#define RSESCI_EAUT                         2
/* --- Trace Mode ---------------------------------------------------------- */
#define RSESCI_TRACE_WRITE                  0
#define RSESCI_TRACE_VIEW                   1
#define RSESCI_TRACE_AVG                    2
#define RSESCI_TRACE_MAXH                   3
#define RSESCI_TRACE_MINH                   4

/* --- Trace Detector ------------------------------------------------------ */
#define RSESCI_TRACEDET_APEAK               0
#define RSESCI_TRACEDET_NEG                 1
#define RSESCI_TRACEDET_POS                 2
#define RSESCI_TRACEDET_SAMPLE              3
#define RSESCI_TRACEDET_RMS                 4
#define RSESCI_TRACEDET_AVG                 5
#define RSESCI_TRACEDET_QPEAK               6
#define RSESCI_TRACEDET_CAVG                7
#define RSESCI_TRACEDET_CRMS                8

/* --- Expression ---------------------------------------------------------- */
#define RSESCI_MATH_TR1_SUB_TR2             0
#define RSESCI_MATH_TR1_SUB_TR3             1

/* --- Transmission Mode --------------------------------------------------- */
#define RSESCI_TRANS_NEVER                  0
#define RSESCI_TRANS_ALWAYS                 1

/* --- Polarity ------------------------------------------------------------ */
#define RSESCI_POL_POS                      0
#define RSESCI_POL_NEG                      1

/* --- Search Mode --------------------------------------------------------- */
#define RSESCI_MARKER_PMAX                  0
#define RSESCI_MARKER_NMAX                  1
#define RSESCI_MARKER_LMAX                  2
#define RSESCI_MARKER_RMAX                  3
#define RSESCI_MARKER_PMIN                  4
#define RSESCI_MARKER_NMIN                  5
#define RSESCI_MARKER_LMIN                  6
#define RSESCI_MARKER_RMIN                  7

/* --- Mkr Function -------------------------------------------------------- */
#define RSESCI_MARKER_TO_CENTER             0
#define RSESCI_MARKER_TO_STEP               1
#define RSESCI_MARKER_TO_REF                2

/* --- Power Measurement --------------------------------------------------- */
#define RSESCI_POWER_MEAS_AOFF              0
#define RSESCI_POWER_MEAS_PREV              1
#define RSESCI_POWER_MEAS_PEAK              2
#define RSESCI_POWER_MEAS_RMS               3
#define RSESCI_POWER_MEAS_MEAN              4
#define RSESCI_POWER_MEAS_SDEV              5

/* --- Result Type --------------------------------------------------------- */
#define RSESCI_RESULT_CURR                  0
#define RSESCI_RESULT_AVG                   1
#define RSESCI_RESULT_PHOLD                 2

/* --- Measurement --------------------------------------------------------- */
#define RSESCI_FDOMAIN_MEAS_OFF             0
#define RSESCI_FDOMAIN_MEAS_CPOW            1
#define RSESCI_FDOMAIN_MEAS_ACP             2
#define RSESCI_FDOMAIN_MEAS_MCAC            3
#define RSESCI_FDOMAIN_MEAS_OBW             4
#define RSESCI_FDOMAIN_MEAS_CN              5
#define RSESCI_FDOMAIN_MEAS_CN0             6

/* --- Standard ------------------------------------------------------------ */
#define RSESCI_STANDARD_NONE                0
#define RSESCI_STANDARD_NADC                1
#define RSESCI_STANDARD_TETRA               2
#define RSESCI_STANDARD_PDC                 3
#define RSESCI_STANDARD_PHS                 4
#define RSESCI_STANDARD_CDPD                5
#define RSESCI_STANDARD_FWCD                6
#define RSESCI_STANDARD_RWCD                7
#define RSESCI_STANDARD_F8CD                8
#define RSESCI_STANDARD_R8CD                9
#define RSESCI_STANDARD_F19C                10
#define RSESCI_STANDARD_R19C                11
#define RSESCI_STANDARD_FW3G                12
#define RSESCI_STANDARD_RW3G                13
#define RSESCI_STANDARD_D2CD                14
#define RSESCI_STANDARD_S2CD                15
#define RSESCI_STANDARD_M2CD                16
#define RSESCI_STANDARD_FIS95C0             17
#define RSESCI_STANDARD_RIS95C0             18
#define RSESCI_STANDARD_FIS95C1             19
#define RSESCI_STANDARD_RIS95C1             20
#define RSESCI_STANDARD_TCDM                21
#define RSESCI_STANDARD_AWL                 22
#define RSESCI_STANDARD_BWL                 23
#define RSESCI_STANDARD_USER                24
    
/* --- Size ---------------------------------------------------------------- */
#define RSESCI_WINDOW_SMALL                 0
#define RSESCI_WINDOW_LARGE                 1

/* --- Channel Bandwidth --------------------------------------------------- */
#define RSESCI_BWID_TX                      0
#define RSESCI_BWID_ADJ                     1
#define RSESCI_BWID_ALT1                    2
#define RSESCI_BWID_ALT2                    3
#define RSESCI_BWID_ALT3                    4
#define RSESCI_BWID_ALT4                    5
#define RSESCI_BWID_ALT5                    6
#define RSESCI_BWID_ALT6                    7
#define RSESCI_BWID_ALT7                    8
#define RSESCI_BWID_ALT8                    9
#define RSESCI_BWID_ALT9                    10
#define RSESCI_BWID_ALT10                   11
#define RSESCI_BWID_ALT11                   12
#define RSESCI_BWID_TX2                     13
#define RSESCI_BWID_TX3                     14
#define RSESCI_BWID_TX4                     15
#define RSESCI_BWID_TX5                     16
#define RSESCI_BWID_TX6                     17
#define RSESCI_BWID_TX7                     18
#define RSESCI_BWID_TX8                     19
#define RSESCI_BWID_TX9                     20
#define RSESCI_BWID_TX10                    21
#define RSESCI_BWID_TX11                    22

/* --- ACP Reference Channel ----------------------------------------------- */
#define RSESCI_ACP_REFERENCE_TX1            0
#define RSESCI_ACP_REFERENCE_TX2            1
#define RSESCI_ACP_REFERENCE_TX3            2
#define RSESCI_ACP_REFERENCE_TX4            3
#define RSESCI_ACP_REFERENCE_MIN            4
#define RSESCI_ACP_REFERENCE_MAX            5
#define RSESCI_ACP_REFERENCE_LOW_HIGH       6

/* --- Measurement --------------------------------------------------------- */
#define RSESCI_STAT_AOFF                    0
#define RSESCI_STAT_APD                     1
#define RSESCI_STAT_CCDF                    2

/* --- Result Type --------------------------------------------------------- */
#define RSESCI_STAT_RESULT_ALL              0
#define RSESCI_STAT_RESULT_MEAN             1
#define RSESCI_STAT_RESULT_PEAK             2
#define RSESCI_STAT_RESULT_CFAC             3

/* --- Scan Mode ----------------------------------------------------------- */
#define RSESCI_SCAN_CONT                    1
#define RSESCI_SCAN_SING                    0

/* --- Final Detector ------------------------------------------------------ */
#define RSESCI_DETECTOR_MAXP                0
#define RSESCI_DETECTOR_MINP                1
#define RSESCI_DETECTOR_RMS                 2
#define RSESCI_DETECTOR_AVG                 3
#define RSESCI_DETECTOR_QPEAK               4
#define RSESCI_DETECTOR_CAV                 5
#define RSESCI_DETECTOR_CRMS                6

/* --- Search Method ------------------------------------------------------- */
#define RSESCI_SEARCH_SUBR                  0
#define RSESCI_SEARCH_PEAK                  1

/* --- Indication ---------------------------------------------------------- */
#define RSESCI_SYMBOL_OFF                   0
#define RSESCI_SYMBOL_CROSS                 1

/* --- Measurement --------------------------------------------------------- */
#define RSESCI_VNET_MEAS_FINAL              1
#define RSESCI_VNET_MEAS_PRESCAN            0

/* --- Protective Earth ---------------------------------------------------- */
#define RSESCI_EARTH_GROUNDED               0
#define RSESCI_EARTH_FLOATING               1

/* --- Phase --------------------------------------------------------------- */
#define RSESCI_PHASE_N                      0
#define RSESCI_PHASE_L1                     1
#define RSESCI_PHASE_L2                     2
#define RSESCI_PHASE_L3                     3

/* --- Demodulation -------------------------------------------------------- */
#define RSESCI_DEMOD_OFF                    0
#define RSESCI_DEMOD_AM                     1
#define RSESCI_DEMOD_FM                     2

/* --- Peak List Sort Mode ------------------------------------------------- */
#define RSESCI_X                            0
#define RSESCI_Y                            1

/* --- Calibration Source  ------------------------------------------------- */
#define RSESCI_RF_INPUT                     0
#define RSESCI_INT_CALIB_SOURCE             1

/* --- Clear --------------------------------------------------------------- */
#define RSESCI_CLEAR_ALL                    0
#define RSESCI_CLEAR_FILE                   1

/* --- File Operations ----------------------------------------------------- */
#define RSESCI_FILE_MAN_CDRIVE              0
#define RSESCI_FILE_MAN_CDIR                1
#define RSESCI_FILE_MAN_MDIR                2
#define RSESCI_FILE_MAN_RDIR                3
#define RSESCI_FILE_MAN_COPY                4
#define RSESCI_FILE_MAN_MOVE                5
#define RSESCI_FILE_MAN_DELETE              6
#define RSESCI_FILE_MAN_FORMAT              7

/* --- Instrument Mode ----------------------------------------------------- */
#define RSESCI_INSTRUMENT_MODE_SANALYZER    0
#define RSESCI_INSTRUMENT_MODE_RECEIVER     1
#define RSESCI_INSTRUMENT_MODE_ADEMOD       2
#define RSESCI_INSTRUMENT_MODE_IFANALYZER   3

/* --- V-network Type ------------------------------------------------------ */
#define RSESCI_VNET_OFF                     0
#define RSESCI_VNET_TWO                     1
#define RSESCI_VNET_FOUR                    2
#define RSESCI_VNET_ESH3Z5                  3
#define RSESCI_VNET_ESH2Z5                  4
#define RSESCI_VNET_ENV4200                 5
#define RSESCI_VNET_ENV216                  6	

/* --- Interface Type ------------------------------------------------------ */
#define RSESCI_INTF_GPIB                    0
#define RSESCI_INTF_TTL                     1

/* --- Screen Mode --------------------------------------------------------- */
#define RSESCI_SCREEN_SINGLE                0
#define RSESCI_SCREEN_SPLIT                 1

/* --- Coupling Mode ------------------------------------------------------- */
#define RSESCI_INST_COUP_NONE               0
#define RSESCI_INST_COUP_RLEVEL             1
#define RSESCI_INST_COUP_CF_A               2
#define RSESCI_INST_COUP_CF_B               3

#define RSESCI_INST_COUP_CENT               0
#define RSESCI_INST_COUP_SPAN               1
#define RSESCI_INST_COUP_ATT                2
#define RSESCI_INST_COUP_PROT               3
#define RSESCI_INST_COUP_GAIN               4
#define RSESCI_INST_COUP_PRES               5
#define RSESCI_INST_COUP_DEM                6
#define RSESCI_INST_COUP_BWID               7
/* --- Sweep Mode ---------------------------------------------------------- */
#define RSESCI_SINGLE_SWEEP                 0
#define RSESCI_CONTINUOUS_SWEEP             1

/* --- Destination --------------------------------------------------------- */
#define RSESCI_HARDCOPY_DISK                0
#define RSESCI_HARDCOPY_PRINTER             1
#define RSESCI_HARDCOPY_CLIPBOARD           2

/* --- Data Format --------------------------------------------------------- */
#define RSESCI_HARDCOPY_WMF                 0
#define RSESCI_HARDCOPY_GDI                 1
#define RSESCI_HARDCOPY_EWMF                2
#define RSESCI_HARDCOPY_BMP                 3

/* --- Page Orientation ---------------------------------------------------- */
#define RSESCI_HARDCOPY_PORTRAIT            0
#define RSESCI_HARDCOPY_LANDSCAPE           1

/* --- Hardcopy Items ------------------------------------------------------ */
#define RSESCI_HARDCOPY_ALL                 0
#define RSESCI_HARDCOPY_TABLE               1
#define RSESCI_HARDCOPY_TRACE               2

/* --- Color Map ----------------------------------------------------------- */
#define RSESCI_CMAP_1                       1
#define RSESCI_CMAP_2                       2
#define RSESCI_CMAP_3                       3
#define RSESCI_CMAP_4                       4
#define RSESCI_CMAP_5                       5
#define RSESCI_CMAP_6                       6
#define RSESCI_CMAP_7                       7
#define RSESCI_CMAP_8                       8
#define RSESCI_CMAP_9                       9
#define RSESCI_CMAP_10                      10
#define RSESCI_CMAP_11                      11
#define RSESCI_CMAP_12                      12
#define RSESCI_CMAP_13                      13
#define RSESCI_CMAP_14                      14
#define RSESCI_CMAP_15                      15
#define RSESCI_CMAP_16                      16
#define RSESCI_CMAP_17                      17
#define RSESCI_CMAP_18                      18
#define RSESCI_CMAP_19                      19
#define RSESCI_CMAP_20                      20
#define RSESCI_CMAP_21                      21
#define RSESCI_CMAP_22                      22
#define RSESCI_CMAP_23                      23
#define RSESCI_CMAP_24                      24
#define RSESCI_CMAP_25                      25
#define RSESCI_CMAP_26                      26
#define RSESCI_CMAP_27                      27
#define RSESCI_CMAP_28                      28
#define RSESCI_CMAP_29                      29
#define RSESCI_CMAP_30                      30
#define RSESCI_CMAP_31                      31
#define RSESCI_CMAP_32                      32
#define RSESCI_CMAP_33                      33
#define RSESCI_CMAP_34                      34

/* --- Predefined Colors --------------------------------------------------- */
#define RSESCI_USER_DEFINED                -1
#define RSESCI_BLACK                        0
#define RSESCI_BLUE                         1
#define RSESCI_BROWN                        2
#define RSESCI_GREEN                        3
#define RSESCI_CYAN                         4
#define RSESCI_RED                          5
#define RSESCI_MAGNETA                      6
#define RSESCI_YELLOW                       7
#define RSESCI_WHITE                        8
#define RSESCI_DGRAY                        9
#define RSESCI_LGRAY                        10
#define RSESCI_LBLUE                        11
#define RSESCI_LGREEN                       12
#define RSESCI_LCYAN                        13
#define RSESCI_LRED                         14
#define RSESCI_LMAGNETA                     15

/* --- Predefined Colors --------------------------------------------------- */
#define RSESCI_DEFAULT_USER_DEFINED         0
#define RSESCI_DEFAULT_COLOR_SET            1
#define RSESCI_DEFAULT_SCREEN_COLORS        2

/* --- Default Colors ------------------------------------------------------ */
#define RSESCI_DEFAULT_1                    1
#define RSESCI_DEFAULT_2                    2

/* --- Result Display ------------------------------------------------------ */
#define RSESCI_FM_SUMMARY                   0
#define RSESCI_DEMOD_FM_SIG                 1
#define RSESCI_AFS_FM_SIG                   2
#define RSESCI_RFS_FM_SIG                   3
#define RSESCI_PM_SUMMARY                   4
#define RSESCI_DEMOD_PM_SIG                 5
#define RSESCI_AFS_PM_SIG                   6
#define RSESCI_AM_SUMMARY                   7
#define RSESCI_DEMOD_AM_SIG                 8
#define RSESCI_AFS_AM_SIG                   9
#define RSESCI_RFP_AM_SIG                   10
#define RSESCI_DEMOD_AM_SIG_REL             11
#define RSESCI_AM_SUMMARY_REL               12
#define RSESCI_AFS_AM_SIG_REL               13

/* --- Display Size -------------------------------------------------------- */
#define RSESCI_SCREEN_SMALL                 0
#define RSESCI_SCREEN_LARGE                 1

/* --- Averaging Type ------------------------------------------------------ */
#define RSESCI_AVERAGE_LINEAR               0
#define RSESCI_AVERAGE_VIDEO                1

/* --- Angle Units --------------------------------------------------------- */
#define RSESCI_ANGLE_UNITS_RAD              0
#define RSESCI_ANGLE_UNITS_DEG              1

/* --- Modulation Measurement ---------------------------------------------- */
#define RSESCI_MOD_MEAS_PPEAK               0
#define RSESCI_MOD_MEAS_MPEAK               1
#define RSESCI_MOD_MEAS_MIDDLE              2
#define RSESCI_MOD_MEAS_RMS                 3

/* --- Demodulation Type --------------------------------------------------- */
#define RSESCI_DEMOD_TYPE_AM                0
#define RSESCI_DEMOD_TYPE_FM                1
#define RSESCI_DEMOD_TYPE_PM                2
#define RSESCI_DEMOD_TYPE_AM_REL            3

/* --- Measurement Type ---------------------------------------------------- */
#define RSESCI_MEASUREMENT_IMM              0
#define RSESCI_MEASUREMENT_AVERAGE          1

/* --- Tracking Generator Measurement -------------------------------------- */
#define RSESCI_CORRECTION_TRAN              0
#define RSESCI_CORRECTION_REFL              1

/* --- Tracking Generator Calibration -------------------------------------- */
#define RSESCI_ACQ_THR                      0
#define RSESCI_ACQ_OPEN                     1

/* ---  Limit Line --------------------------------------------------------- */
#define RSESCI_LIMIT_LOWER                  0
#define RSESCI_LIMIT_UPPER                  1

/* --- Domain -------------------------------------------------------------- */
#define RSESCI_DOMAIN_FREQ                  0
#define RSESCI_DOMAIN_TIME                  1

/* --- Limit --------------------------------------------------------------- */
#define RSESCI_LIMIT_X                      2

/* --- Parity -------------------------------------------------------------- */
#define RSESCI_NONE                         0
#define RSESCI_EVEN                         1
#define RSESCI_ODD                          2

/* --- Port Type ----------------------------------------------------------- */
#define RSESCI_INPUT                        0
#define RSESCI_OUTPUT                       1

/* --- Data Set Items ------------------------------------------------------ */
#define RSESCI_DATA_SET_NONE                0
#define RSESCI_DATA_SET_DEFAULT             1
#define RSESCI_DATA_SET_ALL                 2
#define RSESCI_DATA_SET_CURRENT             3
#define RSESCI_DATA_SET_TRACES              4
#define RSESCI_DATA_SET_FINAL_LIST          5
#define RSESCI_DATA_SET_LIMIT_LINES         6
#define RSESCI_DATA_SET_CALIBRATION         7
#define RSESCI_DATA_SET_TRANSDUCERS         8
#define RSESCI_DATA_SET_HCOPY               9
#define RSESCI_DATA_SET_SCAN               10

/* --- Decimal Point Notation ---------------------------------------------- */
#define RSESCI_DEC_SEPARATOR_POINT          0
#define RSESCI_DEC_SEPARATOR_COMMA          1

/* --- Mixed Instrument Mode ----------------------------------------------- */
#define RSESCI_MIXED_MODE_DISPLAY_SANALYZER 0
#define RSESCI_MIXED_MODE_DISPLAY_RECEIVER  1

/* --- Result Type --------------------------------------------------------- */
#define RSESCI_RESULT_TYPE_OFF              0
#define RSESCI_RESULT_TYPE_WRITE            1
#define RSESCI_RESULT_TYPE_AVERAGE          2
#define RSESCI_RESULT_TYPE_MAXHOLD          3
#define RSESCI_RESULT_TYPE_MINHOLD          4
#define RSESCI_RESULT_TYPE_VIEW             5

/* --- Compatibility Mode -------------------------------------------------- */
#define RSESCI_OFF                          0
#define RSESCI_FSP                          1
	
/* --- Input Type ---------------------------------------------------------- */
#define RSESCI_INPUT_TYPE_1                 0
#define RSESCI_INPUT_TYPE_2                 1
	
/* --- Set PLL Bandwidth --------------------------------------------------- */
#define RSESCI_PLL_BWIDTH_AUTO              0
#define RSESCI_PLL_BWIDTH_HIGH              1
#define RSESCI_PLL_BWIDTH_MED               2
#define RSESCI_PLL_BWIDTH_LOW               3
	
/* --- Get PLL Bandwidth --------------------------------------------------- */
#define RSESCI_PLL_BWIDTH_WIDE              0
#define RSESCI_PLL_BWIDTH_NORMAL            1
#define RSESCI_PLL_BWIDTH_NARROW            2	
	
/* --- FFT Filter Mode ----------------------------------------------------- */
#define RSESCI_FFT_FILTER_AUTO              0
#define RSESCI_FFT_FILTER_WIDE              1
#define RSESCI_FFT_FILTER_NARR              2
	
/* --- Signal Statistic Probability ---------------------------------------- */
#define RSESCI_STAT_PROB_0_1                0
#define RSESCI_STAT_PROB_1                  1
#define RSESCI_STAT_PROB_10                 2
	
/* --- Signal Statistic Units ---------------------------------------------- */
#define RSESCI_SSTAT_UNIT_ABS               0
#define RSESCI_SSTAT_UNIT_PCT               1
	
/* --- Sweep Mode ---------------------------------------------------------- */
#define RSESCI_SWEEP_MODE_AUTO              0
#define RSESCI_SWEEP_MODE_LIST              1
	
/* --- Sweep List Filter Type ---------------------------------------------- */
#define RSESCI_LIST_FTYPE_NORM              0
#define RSESCI_LIST_FTYPE_CHAN              1
#define RSESCI_LIST_FTYPE_RRC               2
#define RSESCI_LIST_FTYPE_P5                3
#define RSESCI_LIST_FTYPE_NOISE             4
#define RSESCI_LIST_FTYPE_PULSE             5
	
/* --- Read Additional Trace Data ------------------------------------------ */
#define RSESCI_TRAC_ABIT                    0
#define RSESCI_TRAC_PWCD                    1
	
/* --- Tracking Generator Power Sweep -------------------------------------- */
#define RSESCI_TGEN_POW_FIX                 0
#define RSESCI_TGEN_POW_SWE                 1
	
/* --- Analog Demodulation Filter Type ------------------------------------- */
#define RSESCI_FM_FILTER_HP                 0
#define RSESCI_FM_FILTER_LP                 1
#define RSESCI_FM_FILTER_LP_REL             2
#define RSESCI_FM_FILTER_DEEMP              3	
	
/* --- Phase Wrapping ------------------------------------------------------ */
#define RSESCI_PHASE_WRAP_PHAS              0
#define RSESCI_PHASE_WRAP_UPH               1
	
/* --- Signal Destination -------------------------------------------------- */
#define RSESCI_IQ_CAL_IHIG                  0
#define RSESCI_IQ_CAL_ILOW                  1
#define RSESCI_IQ_CAL_QHIG                  2
#define RSESCI_IQ_CAL_QLOW                  3
	
/* --- Signal Destination -------------------------------------------------- */
#define RSESCI_IQ_CAL_VOLT_0                0
#define RSESCI_IQ_CAL_VOLT_0_1              1
#define RSESCI_IQ_CAL_VOLT_0_178            2
#define RSESCI_IQ_CAL_VOLT_0_316            3
#define RSESCI_IQ_CAL_VOLT_0_562            4
#define RSESCI_IQ_CAL_VOLT_1_0              5	

/* --- Pulse Frequency ----------------------------------------------------- */
#define RSESCI_IQ_CAL_FREQ_10KHZ            0
#define RSESCI_IQ_CAL_FREQ_62KHZ            1
#define RSESCI_IQ_CAL_FREQ_80KHZ            2
#define RSESCI_IQ_CAL_FREQ_100KHZ           3
#define RSESCI_IQ_CAL_FREQ_102KHZ           4
#define RSESCI_IQ_CAL_FREQ_200KHZ           5
#define RSESCI_IQ_CAL_FREQ_500KHZ           6
#define RSESCI_IQ_CAL_FREQ_1MHZ             7
#define RSESCI_IQ_CAL_FREQ_2MHZ             8
#define RSESCI_IQ_CAL_FREQ_4MHZ             9
	
/* --- Baseband Source ----------------------------------------------------- */
#define RSESCI_IQ_CAL_BBSRC_IQ              0
#define RSESCI_IQ_CAL_BBSRC_GND             1
#define RSESCI_IQ_CAL_BBSRC_CALD            2
#define RSESCI_IQ_CAL_BBSRC_CALP            3
	
/* --- Hardcopy Output ----------------------------------------------------- */
#define RSESCI_HCOP_SCREEN                  0
#define RSESCI_HCOP_TREP                    1
	
/* --- Hardcopy Page Setting ----------------------------------------------- */
#define RSESCI_TREP_HEAD                    0
#define RSESCI_TREP_DIAG                    1
#define RSESCI_TREP_FRES                    2
#define RSESCI_TREP_PAGE                    3
#define RSESCI_TREP_STAB                    4
#define RSESCI_TREP_SRES                    5
#define RSESCI_TREP_TDST                    6
#define RSESCI_TREP_TRAN                    7
	
/* --- Hardcopy Header ----------------------------------------------------- */
#define RSESCI_TREP_LOGO                    0
#define RSESCI_TREP_LINE                    1
#define RSESCI_TREP_LTITLE                  2
#define RSESCI_TREP_LTEXT                   3
	
/* --- Hardcopy Header State ----------------------------------------------- */
#define RSESCI_TREP_ALW                     0
#define RSESCI_TREP_ONCE                    1
#define RSESCI_TREP_NEV                     2	
	
/* --- Hardcopy Header Operations ------------------------------------------ */
#define RSESCI_TREP_LOAD                    0
#define RSESCI_TREP_SAVE                    1
#define RSESCI_TREP_DEL                     2
		
/* --- IF Shift ------------------------------------------------------------ */
#define RSESCI_VAL_IF_SHIFT_OFF             0
#define RSESCI_VAL_IF_SHIFT_A               1
#define RSESCI_VAL_IF_SHIFT_B               2
#define RSESCI_VAL_IF_SHIFT_AUTO            3
/* --- PLL Bandwidth ------------------------------------------------------- */ 
#define RSESCI_VAL_NORM                     0	
#define RSESCI_VAL_WIDE                     1	
/* --- TOI Marker -----------------------------------------------------------*/ 	
#define	RSESCI_VAL_CALC                     0
#define RSESCI_VAL_SEAR                     1	
/* --- Preselector Band -----------------------------------------------------*/ 		
#define RSESCI_BAND_A						0
#define RSESCI_BAND_B						1
	
#define RSESCI_SWITCH_OVER_FREQ_BBAN        0
/*****************************************************************************/
/*= GLOBAL USER-CALLABLE FUNCTION DECLARATIONS (Exportable Functions) =======*/
/*****************************************************************************/

ViStatus _VI_FUNC rsesci_init (ViRsrc resourceName, ViBoolean IDQuery,
                               ViBoolean resetDevice, ViSession* instrumentHandle);
ViStatus _VI_FUNC rsesci_ReadSpectrum (ViSession instrumentHandle,
                                       ViInt32 measurementMode,
                                       ViInt32 frequencyParameter,
                                       ViReal64 startFrequency,
                                       ViReal64 stopFrequency,
                                       ViInt32* samplesReturned,
                                       ViReal64 _VI_FAR traceData[]);
ViStatus _VI_FUNC rsesci_SetCenterFrequency (ViSession instrumentHandle,
                                             ViInt32 window,
                                             ViReal64 centerFrequency);
ViStatus _VI_FUNC rsesci_GetCenterFrequency (ViSession instrumentHandle,
                                             ViInt32 window,
                                             ViReal64* centerFrequency);
ViStatus _VI_FUNC rsesci_SetStartFrequency (ViSession instrumentHandle,
                                            ViInt32 window,
                                            ViReal64 startFrequency);
ViStatus _VI_FUNC rsesci_GetStartFrequency (ViSession instrumentHandle,
                                            ViInt32 window,
                                            ViReal64* startFrequency);
ViStatus _VI_FUNC rsesci_SetStopFrequency (ViSession instrumentHandle,
                                           ViInt32 window, ViReal64 stopFrequency);
ViStatus _VI_FUNC rsesci_GetStopFrequency (ViSession instrumentHandle,
                                           ViInt32 window, ViReal64* stopFrequency);
ViStatus _VI_FUNC rsesci_SetFrequencyOffset (ViSession instrumentHandle,
                                             ViInt32 window,
                                             ViReal64 frequencyOffset);
ViStatus _VI_FUNC rsesci_GetFrequencyOffset (ViSession instrumentHandle,
                                             ViInt32 window,
                                             ViReal64* frequencyOffset);
ViStatus _VI_FUNC rsesci_SetFrequencyMode (ViSession instrumentHandle,
                                           ViInt32 window, ViInt32 frequencyMode);
ViStatus _VI_FUNC rsesci_GetFrequencyMode (ViSession instrumentHandle,
                                           ViInt32 window, ViInt32* frequencyMode);
ViStatus _VI_FUNC rsesci_SetCenterFrequencyStepWidth (ViSession instrumentHandle,
                                                      ViInt32 window,
                                                      ViReal64 stepWidth);
ViStatus _VI_FUNC rsesci_GetCenterFrequencyStepWidth (ViSession instrumentHandle,
                                                      ViInt32 window,
                                                      ViReal64* stepWidth);
ViStatus _VI_FUNC rsesci_SetCenterFrequencyStepLink (ViSession instrumentHandle,
                                                     ViInt32 window,
                                                     ViInt32 stepLink);
ViStatus _VI_FUNC rsesci_GetCenterFrequencyStepLink (ViSession instrumentHandle,
                                                     ViInt32 window,
                                                     ViInt32* stepLink);
ViStatus _VI_FUNC rsesci_SetCenterFrequencyStepLinkFactor
             (ViSession instrumentHandle, ViInt32 window, ViInt32 stepLinkFactor);
ViStatus _VI_FUNC rsesci_GetCenterFrequencyStepLinkFactor
             (ViSession instrumentHandle, ViInt32 window, ViInt32* stepLinkFactor);
ViStatus _VI_FUNC rsesci_SetSignalTracking (ViSession instrumentHandle,
                                            ViInt32 window,
                                            ViBoolean signalTracking);
ViStatus _VI_FUNC rsesci_GetSignalTracking (ViSession instrumentHandle,
                                            ViInt32 window,
                                            ViBoolean* signalTracking);
ViStatus _VI_FUNC rsesci_SetSignalTrackingBandwidth (ViSession instrumentHandle,
                                                     ViInt32 window,
                                                     ViReal64 signalTrackingBandwidth);
ViStatus _VI_FUNC rsesci_GetSignalTrackingBandwidth (ViSession instrumentHandle,
                                                     ViInt32 window,
                                                     ViReal64* signalTrackingBandwidth);
ViStatus _VI_FUNC rsesci_SetSignalTrackingThreshold (ViSession instrumentHandle,
                                                     ViInt32 window,
                                                     ViReal64 signalTrackingThreshold);
ViStatus _VI_FUNC rsesci_GetSignalTrackingThreshold (ViSession instrumentHandle,
                                                     ViInt32 window,
                                                     ViReal64* signalTrackingThreshold);
ViStatus _VI_FUNC rsesci_SetSignalTrackingTrace (ViSession instrumentHandle,
                                                 ViInt32 window,
                                                 ViInt32 signalTrackingTrace);
ViStatus _VI_FUNC rsesci_GetSignalTrackingTrace (ViSession instrumentHandle,
                                                 ViInt32 window,
                                                 ViInt32* signalTrackingTrace);
ViStatus _VI_FUNC rsesci_SetFrequencySpan (ViSession instrumentHandle,
                                           ViInt32 window, ViReal64 frequencySpan);
ViStatus _VI_FUNC rsesci_GetFrequencySpan (ViSession instrumentHandle,
                                           ViInt32 window, ViReal64* frequencySpan);
ViStatus _VI_FUNC rsesci_SetFrequencyFullSpan (ViSession instrumentHandle,
                                               ViInt32 window);
ViStatus _VI_FUNC rsesci_SetReferenceLevel (ViSession instrumentHandle,
                                            ViInt32 window,
                                            ViReal64 referenceLevel);
ViStatus _VI_FUNC rsesci_GetReferenceLevel (ViSession instrumentHandle,
                                            ViInt32 window,
                                            ViReal64* referenceLevel);

ViStatus _VI_FUNC rsesci_GetACPStandardCatalog (ViSession instrumentHandle,
                                                ViInt32 window,
                                                ViInt32 arraySize,
                                                ViChar catalog[]);

ViStatus _VI_FUNC rsesci_SetReferenceLevelOffset (ViSession instrumentHandle,
                                                  ViInt32 window,
                                                  ViReal64 referenceLevelOffset);
ViStatus _VI_FUNC rsesci_GetReferenceLevelOffset (ViSession instrumentHandle,
                                                  ViInt32 window,
                                                  ViReal64* referenceLevelOffset);
ViStatus _VI_FUNC rsesci_SetReferenceLevelPosition (ViSession instrumentHandle,
                                                    ViInt32 window,
                                                    ViReal64 referenceLevelPosition);
ViStatus _VI_FUNC rsesci_GetReferenceLevelPosition (ViSession instrumentHandle,
                                                    ViInt32 window,
                                                    ViReal64* referenceLevelPosition);
ViStatus _VI_FUNC rsesci_SetReferenceLevelPositionValue (ViSession instrumentHandle,
                                                         ViInt32 window,
                                                         ViReal64 referenceLevelPosition);
ViStatus _VI_FUNC rsesci_GetReferenceLevelPositionValue (ViSession instrumentHandle,
                                                         ViInt32 window,
                                                         ViReal64* referenceLevelPosition);
ViStatus _VI_FUNC rsesci_SetYAxisScaleDivision (ViSession instrumentHandle,
                                                ViInt32 window, ViReal64 yScaleDiv);
ViStatus _VI_FUNC rsesci_GetYAxisScaleDivision (ViSession instrumentHandle,
                                                ViInt32 window,
                                                ViReal64* yScaleDiv);
ViStatus _VI_FUNC rsesci_SetLevelAxisRange (ViSession instrumentHandle,
                                            ViInt32 window,
                                            ViReal64 levelAxisRange);
ViStatus _VI_FUNC rsesci_GetLevelAxisRange (ViSession instrumentHandle,
                                            ViInt32 window,
                                            ViReal64* levelAxisRange);
ViStatus _VI_FUNC rsesci_SetLevelAxisMinimum (ViSession instrumentHandle,
                                              ViInt32 window,
                                              ViReal64 levelAxisMinimum);
ViStatus _VI_FUNC rsesci_GetLevelAxisMinimum (ViSession instrumentHandle,
                                              ViInt32 window,
                                              ViReal64* levelAxisMinimum);
ViStatus _VI_FUNC rsesci_SetLevelAxisRangeSpacing (ViSession instrumentHandle,
                                                   ViInt32 window,
                                                   ViInt32 levelAxisRangeSpacing);
ViStatus _VI_FUNC rsesci_GetLevelAxisRangeSpacing (ViSession instrumentHandle,
                                                   ViInt32 window,
                                                   ViInt32* levelAxisRangeSpacing);
ViStatus _VI_FUNC rsesci_SetLevelAxisUnit (ViSession instrumentHandle,
                                           ViInt32 window, ViInt32 levelAxisUnit);
ViStatus _VI_FUNC rsesci_GetLevelAxisUnit (ViSession instrumentHandle,
                                           ViInt32 window, ViInt32* levelAxisUnit);
ViStatus _VI_FUNC rsesci_SetLevelAxisScaling (ViSession instrumentHandle,
                                              ViInt32 window,
                                              ViInt32 levelAxisScaling);
ViStatus _VI_FUNC rsesci_GetLevelAxisScaling (ViSession instrumentHandle,
                                              ViInt32 window,
                                              ViInt32* levelAxisScaling);
ViStatus _VI_FUNC rsesci_SetRFInputCoupling (ViSession instrumentHandle,
                                             ViInt32 RFInputCoupling);
ViStatus _VI_FUNC rsesci_GetRFInputCoupling (ViSession instrumentHandle,
                                             ViInt32* RFInputCoupling);
ViStatus _VI_FUNC rsesci_SetRFInputAttenuation (ViSession instrumentHandle,
                                                ViInt32 window,
                                                ViReal64 attenuation);
ViStatus _VI_FUNC rsesci_GetRFInputAttenuation (ViSession instrumentHandle,
                                                ViInt32 window,
                                                ViReal64* attenuation);
ViStatus _VI_FUNC rsesci_SetRFInputAttenuationAuto (ViSession instrumentHandle,
                                                    ViInt32 window,
                                                    ViBoolean attenuationAuto);
ViStatus _VI_FUNC rsesci_GetRFInputAttenuationAuto (ViSession instrumentHandle,
                                                    ViInt32 window,
                                                    ViBoolean* attenuationAuto);
ViStatus _VI_FUNC rsesci_SetRFInputAttenuationProtection (ViSession instrumentHandle,
                                                          ViInt32 window,
                                                          ViBoolean attenuationProtection);
ViStatus _VI_FUNC rsesci_GetRFInputAttenuationProtection (ViSession instrumentHandle,
                                                          ViInt32 window,
                                                          ViBoolean* attenuationProtection);
ViStatus _VI_FUNC rsesci_ResetRFInputAttenuationProtection
             (ViSession instrumentHandle, ViInt32 window);
ViStatus _VI_FUNC rsesci_SetRFInputImpedance (ViSession instrumentHandle,
                                              ViInt32 window,
                                              ViInt32 RFInputImpedance);
ViStatus _VI_FUNC rsesci_GetRFInputImpedance (ViSession instrumentHandle,
                                              ViInt32 window,
                                              ViInt32* RFInputImpedance);
ViStatus _VI_FUNC rsesci_SetRFInputType (ViSession instrumentHandle, ViInt32 window,
                                         ViInt32 inputType);
ViStatus _VI_FUNC rsesci_GetRFInputType (ViSession instrumentHandle, ViInt32 window,
                                         ViInt32* inputType);

ViStatus _VI_FUNC rsesci_SetRFInputSwitchoverFrequency (ViSession instrumentHandle,
                                                        ViInt32 window,
                                                        ViInt32 switchoverFrequency);

ViStatus _VI_FUNC rsesci_GetRFInputSwitchoverFrequency (ViSession instrumentHandle,
                                                        ViInt32 window,
                                                        ViInt32 *switchoverFrequency);

ViStatus _VI_FUNC rsesci_SetPreamplifierAuto (ViSession instrumentHandle,
                                              ViInt32 window,
                                              ViBoolean preamplifierAuto);
ViStatus _VI_FUNC rsesci_GetPreamplifierAuto (ViSession instrumentHandle,
                                              ViInt32 window,
                                              ViBoolean* preamplifierAuto);
ViStatus _VI_FUNC rsesci_SetPreamplifier (ViSession instrumentHandle,
                                          ViInt32 window, ViBoolean preamplifier);
ViStatus _VI_FUNC rsesci_GetPreamplifier (ViSession instrumentHandle,
                                          ViInt32 window, ViBoolean* preamplifier);

ViStatus _VI_FUNC rsesci_SetLowNoisePreamplifier (ViSession instrumentHandle,
                                                  ViInt32 window,
                                                  ViBoolean preamplifier);

ViStatus _VI_FUNC rsesci_GetLowNoisePreamplifier (ViSession instrumentHandle,
                                                  ViInt32 window,
                                                  ViBoolean *preamplifier);

ViStatus _VI_FUNC rsesci_ConfigureInputMixerLevel (ViSession instrumentHandle,
                                                   ViInt32 window,
                                                   ViBoolean automaticSetup,
                                                   ViReal64 power);
ViStatus _VI_FUNC rsesci_SetInputMixerLevelState (ViSession instrumentHandle,
                                                  ViInt32 window,
                                                  ViBoolean automaticSetup);
ViStatus _VI_FUNC rsesci_GetInputMixerLevelState (ViSession instrumentHandle,
                                                  ViInt32 window,
                                                  ViBoolean* automaticSetup);
ViStatus _VI_FUNC rsesci_SetInputMixerPower (ViSession instrumentHandle,
                                             ViInt32 window, ViReal64 power);
ViStatus _VI_FUNC rsesci_GetInputMixerPower (ViSession instrumentHandle,
                                             ViInt32 window, ViReal64* power);
ViStatus _VI_FUNC rsesci_SetMainPLLBandwidth (ViSession instrumentHandle,
                                              ViInt32 window, ViInt32 PLLBandwidth);
ViStatus _VI_FUNC rsesci_GetMainPLLBandwidth (ViSession instrumentHandle,
                                              ViInt32 window,
                                              ViInt32* PLLBandwidth);

ViStatus _VI_FUNC rsesci_SetPLLBandwidthSynchronization (ViSession instrumentHandle,
                                                         ViInt32 window,
                                                         ViInt32 PLLBandwidth);

ViStatus _VI_FUNC rsesci_GetPLLBandwidthSynchronization (ViSession instrumentHandle,
                                                         ViInt32 window,
                                                         ViInt32 *PLLBandwidth);

ViStatus _VI_FUNC rsesci_SetFFTFilterMode (ViSession instrumentHandle,
                                           ViInt32 window, ViInt32 FFTFilterMode);
ViStatus _VI_FUNC rsesci_GetFFTFilterMode (ViSession instrumentHandle,
                                           ViInt32 window, ViInt32* FFTFilterMode);
ViStatus _VI_FUNC rsesci_SetIFBandwidth (ViSession instrumentHandle, ViInt32 window,
                                         ViReal64 IFBandwidth);
ViStatus _VI_FUNC rsesci_GetIFBandwidth (ViSession instrumentHandle, ViInt32 window,
                                         ViReal64* IFBandwidth);
ViStatus _VI_FUNC rsesci_SetDemodulationBandwidth (ViSession instrumentHandle,
                                                   ViInt32 window,
                                                   ViReal64 demodulationBandwidth);
ViStatus _VI_FUNC rsesci_GetDemodulationBandwidth (ViSession instrumentHandle,
                                                   ViInt32 window,
                                                   ViReal64* demodulationBandwidth);
ViStatus _VI_FUNC rsesci_SetResolutionBandwidth (ViSession instrumentHandle,
                                                 ViInt32 window,
                                                 ViReal64 resolutionBandwidth);
ViStatus _VI_FUNC rsesci_GetResolutionBandwidth (ViSession instrumentHandle,
                                                 ViInt32 window,
                                                 ViReal64* resolutionBandwidth);
ViStatus _VI_FUNC rsesci_SetResolutionBandwidthAuto (ViSession instrumentHandle,
                                                     ViInt32 window,
                                                     ViBoolean autoResolutionBandwidth);
ViStatus _VI_FUNC rsesci_GetResolutionBandwidthAuto (ViSession instrumentHandle,
                                                     ViInt32 window,
                                                     ViBoolean* autoResolutionBandwidth);
ViStatus _VI_FUNC rsesci_SetResolutionBandwidthCouplingRatio
             (ViSession instrumentHandle, ViInt32 window, ViReal64 ratio);
ViStatus _VI_FUNC rsesci_GetResolutionBandwidthCouplingRatio
             (ViSession instrumentHandle, ViInt32 window, ViReal64* ratio);
ViStatus _VI_FUNC rsesci_SetResolutionBandwidthFilterType
             (ViSession instrumentHandle, ViInt32 window, ViInt32 filterType);
ViStatus _VI_FUNC rsesci_GetResolutionBandwidthFilterType
             (ViSession instrumentHandle, ViInt32 window, ViInt32* filterType);
ViStatus _VI_FUNC rsesci_SetVideoBandwidth (ViSession instrumentHandle,
                                            ViInt32 window,
                                            ViReal64 videoBandwidth);
ViStatus _VI_FUNC rsesci_GetVideoBandwidth (ViSession instrumentHandle,
                                            ViInt32 window,
                                            ViReal64* videoBandwidth);
ViStatus _VI_FUNC rsesci_SetVideoBandwidthAuto (ViSession instrumentHandle,
                                                ViInt32 window,
                                                ViBoolean autoVideoBandwidth);
ViStatus _VI_FUNC rsesci_GetVideoBandwidthAuto (ViSession instrumentHandle,
                                                ViInt32 window,
                                                ViBoolean* autoVideoBandwidth);
ViStatus _VI_FUNC rsesci_SetVideoBandwidthCouplingRatio (ViSession instrumentHandle,
                                                         ViInt32 window,
                                                         ViReal64 ratio);
ViStatus _VI_FUNC rsesci_GetVideoBandwidthCouplingRatio (ViSession instrumentHandle,
                                                         ViInt32 window,
                                                         ViReal64* ratio);
ViStatus _VI_FUNC rsesci_SetVideoBandwidthMode (ViSession instrumentHandle,
                                                ViInt32 window,
                                                ViInt32 bandwidthMode);
ViStatus _VI_FUNC rsesci_GetVideoBandwidthMode (ViSession instrumentHandle,
                                                ViInt32 window,
                                                ViInt32* bandwidthMode);
ViStatus _VI_FUNC rsesci_ContinueSingleSweep (ViSession instrumentHandle,
                                              ViInt32 window);
ViStatus _VI_FUNC rsesci_GetNumberStartedSweeps (ViSession instrumentHandle,
                                                 ViInt32 window,
                                                 ViInt32* startedScans);
ViStatus _VI_FUNC rsesci_SetSweepMode (ViSession instrumentHandle, ViInt32 window,
                                       ViInt32 continuousSweep);
ViStatus _VI_FUNC rsesci_GetSweepMode (ViSession instrumentHandle, ViInt32 window,
                                       ViInt32* continuousSweep);
ViStatus _VI_FUNC rsesci_SetSweepTime (ViSession instrumentHandle, ViInt32 window,
                                       ViReal64 sweepTime);
ViStatus _VI_FUNC rsesci_GetSweepTime (ViSession instrumentHandle, ViInt32 window,
                                       ViReal64* sweepTime);
ViStatus _VI_FUNC rsesci_SetSweepTimeAuto (ViSession instrumentHandle,
                                           ViInt32 window, ViBoolean autoSweepTime);
ViStatus _VI_FUNC rsesci_GetSweepTimeAuto (ViSession instrumentHandle,
                                           ViInt32 window,
                                           ViBoolean* autoSweepTime);
ViStatus _VI_FUNC rsesci_SetSweepCount (ViSession instrumentHandle, ViInt32 window,
                                        ViInt32 sweepCount);
ViStatus _VI_FUNC rsesci_GetSweepCount (ViSession instrumentHandle, ViInt32 window,
                                        ViInt32* sweepCount);
ViStatus _VI_FUNC rsesci_SetSweepPoints (ViSession instrumentHandle, ViInt32 window,
                                         ViInt32 sweepPoints);
ViStatus _VI_FUNC rsesci_GetSweepPoints (ViSession instrumentHandle, ViInt32 window,
                                         ViInt32* sweepPoints);
ViStatus _VI_FUNC rsesci_SetSingleSweepDisplay (ViSession instrumentHandle,
                                                ViBoolean displayState);
ViStatus _VI_FUNC rsesci_GetSingleSweepDisplay (ViSession instrumentHandle,
                                                ViBoolean* displayState);
ViStatus _VI_FUNC rsesci_SetSweepSpacing (ViSession instrumentHandle,
                                          ViInt32 window, ViInt32 sweepSpacing);
ViStatus _VI_FUNC rsesci_GetSweepSpacing (ViSession instrumentHandle,
                                          ViInt32 window, ViInt32* sweepSpacing);
ViStatus _VI_FUNC rsesci_Abort (ViSession instrumentHandle);
ViStatus _VI_FUNC rsesci_Hold (ViSession instrumentHandle);
ViStatus _VI_FUNC rsesci_SendTrigger (ViSession instrumentHandle, ViInt32 window);
ViStatus _VI_FUNC rsesci_SendTriggerWaitOPC (ViSession instrumentHandle,
                                             ViInt32 window, ViInt32 timeout);
ViStatus _VI_FUNC rsesci_SetTriggerSource (ViSession instrumentHandle,
                                           ViInt32 window, ViInt32 triggerSource);
ViStatus _VI_FUNC rsesci_GetTriggerSource (ViSession instrumentHandle,
                                           ViInt32 window, ViInt32* triggerSource);
ViStatus _VI_FUNC rsesci_SetTriggerLevel (ViSession instrumentHandle,
                                          ViInt32 window, ViInt32 signalType,
                                          ViReal64 triggerLevel);
ViStatus _VI_FUNC rsesci_GetTriggerLevel (ViSession instrumentHandle,
                                          ViInt32 window, ViInt32 signalType,
                                          ViReal64* triggerLevel);
ViStatus _VI_FUNC rsesci_SetTriggerOffset (ViSession instrumentHandle,
                                           ViInt32 window, ViReal64 triggerDelay);
ViStatus _VI_FUNC rsesci_GetTriggerOffset (ViSession instrumentHandle,
                                           ViInt32 window, ViReal64* triggerDelay);
ViStatus _VI_FUNC rsesci_SetTriggerOffsetAdjust (ViSession instrumentHandle,
                                                 ViInt32 window,
                                                 ViBoolean offsetAdjust);
ViStatus _VI_FUNC rsesci_GetTriggerOffsetAdjust (ViSession instrumentHandle,
                                                 ViInt32 window,
                                                 ViBoolean* offsetAdjust);
ViStatus _VI_FUNC rsesci_SetTriggerSourcePolarity (ViSession instrumentHandle,
                                                   ViInt32 window,
                                                   ViInt32 polarity);
ViStatus _VI_FUNC rsesci_GetTriggerSourcePolarity (ViSession instrumentHandle,
                                                   ViInt32 window,
                                                   ViInt32* polarity);
ViStatus _VI_FUNC rsesci_SetGatedTrigger (ViSession instrumentHandle,
                                          ViInt32 window, ViBoolean gatedTrigger);
ViStatus _VI_FUNC rsesci_GetGatedTrigger (ViSession instrumentHandle,
                                          ViInt32 window, ViBoolean* gatedTrigger);
ViStatus _VI_FUNC rsesci_SetGatedTriggerSource (ViSession instrumentHandle,
                                                ViInt32 window,
                                                ViInt32 triggerSource);
ViStatus _VI_FUNC rsesci_GetGatedTriggerSource (ViSession instrumentHandle,
                                                ViInt32 window,
                                                ViInt32* triggerSource);
ViStatus _VI_FUNC rsesci_SetGatedTriggerMode (ViSession instrumentHandle,
                                              ViInt32 window, ViInt32 triggerMode);
ViStatus _VI_FUNC rsesci_GetGatedTriggerMode (ViSession instrumentHandle,
                                              ViInt32 window, ViInt32* triggerMode);
ViStatus _VI_FUNC rsesci_SetGatedTriggerPolarity (ViSession instrumentHandle,
                                                  ViInt32 window,
                                                  ViInt32 triggerPolarity);
ViStatus _VI_FUNC rsesci_GetGatedTriggerPolarity (ViSession instrumentHandle,
                                                  ViInt32 window,
                                                  ViInt32* triggerPolarity);
ViStatus _VI_FUNC rsesci_SetGatedTriggerDelay (ViSession instrumentHandle,
                                               ViInt32 window,
                                               ViReal64 triggerDelay);
ViStatus _VI_FUNC rsesci_GetGatedTriggerDelay (ViSession instrumentHandle,
                                               ViInt32 window,
                                               ViReal64* triggerDelay);
ViStatus _VI_FUNC rsesci_SetGatedTriggerLength (ViSession instrumentHandle,
                                                ViInt32 window,
                                                ViReal64 triggerLength);
ViStatus _VI_FUNC rsesci_GetGatedTriggerLength (ViSession instrumentHandle,
                                                ViInt32 window,
                                                ViReal64* triggerLength);
ViStatus _VI_FUNC rsesci_SetGatedTriggerState (ViSession instrumentHandle,
                                               ViInt32 window, ViInt32 range,
                                               ViInt32 trace,
                                               ViBoolean gateRangeTableState);
ViStatus _VI_FUNC rsesci_GetGatedTriggerState (ViSession instrumentHandle,
                                               ViInt32 window, ViInt32 range,
                                               ViInt32 trace,
                                               ViBoolean* gateRangeTableState);
ViStatus _VI_FUNC rsesci_SetGatedTriggerRange (ViSession instrumentHandle,
                                               ViInt32 window, ViInt32 range,
                                               ViInt32 trace, ViReal64 start,
                                               ViReal64 stop);
ViStatus _VI_FUNC rsesci_GetGatedTriggerRange (ViSession instrumentHandle,
                                               ViInt32 window, ViInt32 range,
                                               ViInt32 trace, ViReal64* start,
                                               ViReal64* stop);
ViStatus _VI_FUNC rsesci_SetGatedTriggerPeriod (ViSession instrumentHandle,
                                                ViInt32 window, ViInt32 trace,
                                                ViReal64 period);
ViStatus _VI_FUNC rsesci_GetGatedTriggerPeriod (ViSession instrumentHandle,
                                                ViInt32 window, ViInt32 trace,
                                                ViReal64* period);
ViStatus _VI_FUNC rsesci_SetGatedTriggerComment (ViSession instrumentHandle,
                                                 ViInt32 window, ViInt32 trace,
                                                 ViString comment);
ViStatus _VI_FUNC rsesci_GetGatedTriggerComment (ViSession instrumentHandle,
                                                 ViInt32 window, ViInt32 trace,
                                                 ViInt32 arraySize,
                                                 ViChar _VI_FAR comment[]);
ViStatus _VI_FUNC rsesci_SetTVTrigger (ViSession instrumentHandle, ViInt32 window,
                                       ViBoolean TVTrigger);
ViStatus _VI_FUNC rsesci_GetTVTrigger (ViSession instrumentHandle, ViInt32 window,
                                       ViBoolean* TVTrigger);
ViStatus _VI_FUNC rsesci_SetTVTriggerVerticalSync (ViSession instrumentHandle,
                                                   ViInt32 window, ViInt32 field);
ViStatus _VI_FUNC rsesci_GetTVTriggerVerticalSync (ViSession instrumentHandle,
                                                   ViInt32 window, ViInt32* field);
ViStatus _VI_FUNC rsesci_SetTVTriggerHorizontalSync (ViSession instrumentHandle,
                                                     ViInt32 window,
                                                     ViInt32 lineNumber);
ViStatus _VI_FUNC rsesci_GetTVTriggerHorizontalSync (ViSession instrumentHandle,
                                                     ViInt32 window,
                                                     ViInt32* lineNumber);
ViStatus _VI_FUNC rsesci_SetTVTriggerPolarity (ViSession instrumentHandle,
                                               ViInt32 window, ViInt32 polarity);
ViStatus _VI_FUNC rsesci_GetTVTriggerPolarity (ViSession instrumentHandle,
                                               ViInt32 window, ViInt32* polarity);
ViStatus _VI_FUNC rsesci_SetTVTriggerLines (ViSession instrumentHandle,
                                            ViInt32 window, ViInt32 linesSystem);
ViStatus _VI_FUNC rsesci_GetTVTriggerLines (ViSession instrumentHandle,
                                            ViInt32 window, ViInt32* linesSystem);
ViStatus _VI_FUNC rsesci_SetTVTriggerCCVS (ViSession instrumentHandle,
                                           ViInt32 window, ViInt32 CCVSSignal);
ViStatus _VI_FUNC rsesci_GetTVTriggerCCVS (ViSession instrumentHandle,
                                           ViInt32 window, ViInt32* CCVSSignal);
ViStatus _VI_FUNC rsesci_SetTraceMode (ViSession instrumentHandle, ViInt32 window,
                                       ViInt32 trace, ViInt32 traceMode);
ViStatus _VI_FUNC rsesci_GetTraceMode (ViSession instrumentHandle, ViInt32 window,
                                       ViInt32 trace, ViInt32* traceMode);
ViStatus _VI_FUNC rsesci_SetTraceBlanking (ViSession instrumentHandle,
                                           ViInt32 window, ViInt32 trace,
                                           ViBoolean traceState);
ViStatus _VI_FUNC rsesci_GetTraceBlanking (ViSession instrumentHandle,
                                           ViInt32 window, ViInt32 trace,
                                           ViBoolean* traceState);
ViStatus _VI_FUNC rsesci_SetTraceDetector (ViSession instrumentHandle,
                                           ViInt32 window, ViInt32 trace,
                                           ViInt32 traceDetector);
ViStatus _VI_FUNC rsesci_GetTraceDetector (ViSession instrumentHandle,
                                           ViInt32 window, ViInt32 trace,
                                           ViInt32* traceDetector);
ViStatus _VI_FUNC rsesci_SetTraceDetectorAuto (ViSession instrumentHandle,
                                               ViInt32 window, ViInt32 trace,
                                               ViBoolean coupleDetector);
ViStatus _VI_FUNC rsesci_GetTraceDetectorAuto (ViSession instrumentHandle,
                                               ViInt32 window, ViInt32 trace,
                                               ViBoolean* coupleDetector);
ViStatus _VI_FUNC rsesci_SetTraceResetBehavior (ViSession instrumentHandle,
                                                ViInt32 window, ViInt32 trace,
                                                ViBoolean switchOffReset);
ViStatus _VI_FUNC rsesci_GetTraceResetBehavior (ViSession instrumentHandle,
                                                ViInt32 window, ViInt32 trace,
                                                ViBoolean* switchOffReset);
ViStatus _VI_FUNC rsesci_SetTraceMath (ViSession instrumentHandle, ViInt32 window,
                                       ViBoolean mathRelation);
ViStatus _VI_FUNC rsesci_GetTraceMath (ViSession instrumentHandle, ViInt32 window,
                                       ViBoolean* mathRelation);
ViStatus _VI_FUNC rsesci_SetTraceMathMode (ViSession instrumentHandle,
                                           ViInt32 mathMode);
ViStatus _VI_FUNC rsesci_GetTraceMathMode (ViSession instrumentHandle,
                                           ViInt32* mathMode);
ViStatus _VI_FUNC rsesci_SetTraceMathPosition (ViSession instrumentHandle,
                                               ViInt32 window, ViReal64 position);
ViStatus _VI_FUNC rsesci_GetTraceMathPosition (ViSession instrumentHandle,
                                               ViInt32 window, ViReal64* position);
ViStatus _VI_FUNC rsesci_SetTraceMathExpression (ViSession instrumentHandle,
                                                 ViInt32 window,
                                                 ViInt32 expression);
ViStatus _VI_FUNC rsesci_GetTraceMathExpression (ViSession instrumentHandle,
                                                 ViInt32 window,
                                                 ViInt32* expression);
ViStatus _VI_FUNC rsesci_SetTraceFeedControl (ViSession instrumentHandle,
                                              ViInt32 control,
                                              ViInt32 transmissionMode);
ViStatus _VI_FUNC rsesci_GetTraceFeedControl (ViSession instrumentHandle,
                                              ViInt32 control,
                                              ViInt32* transmissionMode);

ViStatus _VI_FUNC rsesci_ClearAllActiveTraces (ViSession instrumentHandle,
                                               ViInt32 window);

ViStatus _VI_FUNC rsesci_SetIQTrace (ViSession instrumentHandle, ViInt32 window,
                                     ViBoolean IQTraceState);
ViStatus _VI_FUNC rsesci_GetIQTrace (ViSession instrumentHandle, ViInt32 window,
                                     ViBoolean* IQTraceState);
ViStatus _VI_FUNC rsesci_SetIQTraceAveraging (ViSession instrumentHandle,
                                              ViInt32 window,
                                              ViBoolean IQTraceState);
ViStatus _VI_FUNC rsesci_GetIQTraceAveraging (ViSession instrumentHandle,
                                              ViInt32 window,
                                              ViBoolean* IQTraceState);
ViStatus _VI_FUNC rsesci_SetIQTraceAveragingCount (ViSession instrumentHandle,
                                                   ViInt32 window,
                                                   ViInt32 averageCount);
ViStatus _VI_FUNC rsesci_GetIQTraceAveragingCount (ViSession instrumentHandle,
                                                   ViInt32 window,
                                                   ViInt32* averageCount);
ViStatus _VI_FUNC rsesci_SetIQTraceSynchronization (ViSession instrumentHandle,
                                                    ViInt32 window,
                                                    ViBoolean state);
ViStatus _VI_FUNC rsesci_GetIQTraceSynchronization (ViSession instrumentHandle,
                                                    ViInt32 window,
                                                    ViBoolean* state);
ViStatus _VI_FUNC rsesci_SetIQTraceSamplingRate (ViSession instrumentHandle,
                                                 ViInt32 window,
                                                 ViReal64 samplingRate);
ViStatus _VI_FUNC rsesci_GetIQTraceSamplingRate (ViSession instrumentHandle,
                                                 ViInt32 window,
                                                 ViReal64* samplingRate);
ViStatus _VI_FUNC rsesci_SetIQTraceSettings (ViSession instrumentHandle,
                                             ViInt32 window, ViReal64 samplingRate,
                                             ViInt32 triggerMode, ViInt32 polarity,
                                             ViReal64 bandwidth,
                                             ViInt32 pretriggerSamples,
                                             ViInt32 no_ofSamples);
ViStatus _VI_FUNC rsesci_GetIQTraceSettings (ViSession instrumentHandle,
                                             ViInt32 window, ViReal64* samplingRate,
                                             ViInt32* triggerMode,
                                             ViInt32* polarity, ViReal64* bandwidth,
                                             ViInt32* pretriggerSamples,
                                             ViInt32* no_ofSamples);

ViStatus _VI_FUNC rsesci_GetIQTraceTriggerPositionInSample (ViSession instrumentHandle,
                                                            ViInt32 window,
                                                            ViReal64 *samplingRate);

ViStatus _VI_FUNC rsesci_CopyTrace (ViSession instrumentHandle, ViInt32 window,
                                    ViInt32 sourceTrace, ViInt32 destinationTrace);
ViStatus _VI_FUNC rsesci_ReadTraceData (ViSession instrumentHandle, ViInt32 window,
                                        ViInt32 trace, ViInt32* no_ofPoints,
                                        ViReal64 _VI_FAR traceData[]);
ViStatus _VI_FUNC rsesci_WriteTraceData (ViSession instrumentHandle, ViInt32 window,
                                         ViInt32 trace, ViInt32 no_ofPoints,
                                         ViReal64 _VI_FAR traceData[]);
ViStatus _VI_FUNC rsesci_ReadIQTraceData (ViSession instrumentHandle,
                                          ViInt32 window, ViInt32 bufferSize,
                                          ViInt32* no_ofPoints,
                                          ViReal64 _VI_FAR realParts_I[],
                                          ViReal64 _VI_FAR imaginaryParts_Q[]);
ViStatus _VI_FUNC rsesci_ReadIQTraceDataMemory (ViSession instrumentHandle,
                                                ViInt32 window,
                                                ViInt32 offsetSamples,
                                                ViInt32 no_ofSamples,
                                                ViInt32 bufferSize,
                                                ViInt32* no_ofPoints,
                                                ViReal64 _VI_FAR realParts_I[],
                                                ViReal64 _VI_FAR imaginaryParts_Q[]);
ViStatus _VI_FUNC rsesci_ReadIQTraceDataMemoryAIQ (ViSession instrumentHandle,
                                                   ViInt32 window,
                                                   ViInt32 offsetSamples,
                                                   ViInt32 no_ofSamples,
                                                   ViInt32 bufferSize,
                                                   ViInt32* no_ofPoints,
                                                   ViReal64 _VI_FAR realParts_I[],
                                                   ViReal64 _VI_FAR imaginaryParts_Q[]);
ViStatus _VI_FUNC rsesci_CalibrationTotal (ViSession instrumentHandle,
                                           ViInt32* result);
ViStatus _VI_FUNC rsesci_CalibrationAbort (ViSession instrumentHandle);
ViStatus _VI_FUNC rsesci_CalibrationResults (ViSession instrumentHandle,
                                             ViChar _VI_FAR calibrationResult[]);
ViStatus _VI_FUNC rsesci_SetCalibrationCorrection (ViSession instrumentHandle,
                                                   ViBoolean calibrationState);
ViStatus _VI_FUNC rsesci_GetCalibrationCorrection (ViSession instrumentHandle,
                                                   ViBoolean* calibrationState);
ViStatus _VI_FUNC rsesci_SetYIGCorrectionState (ViSession instrumentHandle,
                                                ViInt32 window, ViBoolean state);
ViStatus _VI_FUNC rsesci_GetYIGCorrectionState (ViSession instrumentHandle,
                                                ViInt32 window, ViBoolean* state);
ViStatus _VI_FUNC rsesci_RunScan (ViSession instrumentHandle);
ViStatus _VI_FUNC rsesci_HoldScan (ViSession instrumentHandle);
ViStatus _VI_FUNC rsesci_ContinueScan (ViSession instrumentHandle);
ViStatus _VI_FUNC rsesci_StopScan (ViSession instrumentHandle);
ViStatus _VI_FUNC rsesci_SetScanMode (ViSession instrumentHandle, ViInt32 scanMode);
ViStatus _VI_FUNC rsesci_GetScanMode (ViSession instrumentHandle,
                                      ViInt32* scanMode);
ViStatus _VI_FUNC rsesci_SetScanTimeDomain (ViSession instrumentHandle,
                                            ViReal64 measurementTime);
ViStatus _VI_FUNC rsesci_GetScanTimeDomain (ViSession instrumentHandle,
                                            ViReal64* measurementTime);
ViStatus _VI_FUNC rsesci_SetScanDisplaySpacing (ViSession instrumentHandle,
                                                ViInt32 window,
                                                ViInt32 displaySpacing);
ViStatus _VI_FUNC rsesci_GetScanDisplaySpacing (ViSession instrumentHandle,
                                                ViInt32 window,
                                                ViInt32* displaySpacing);
ViStatus _VI_FUNC rsesci_SetScanRanges (ViSession instrumentHandle,
                                        ViInt32 number_of_ranges);
ViStatus _VI_FUNC rsesci_GetScanRanges (ViSession instrumentHandle,
                                        ViInt32* number_of_ranges);
ViStatus _VI_FUNC rsesci_SetScanPoints (ViSession instrumentHandle,
                                        ViInt32 number_ofPoints);
ViStatus _VI_FUNC rsesci_SetScanStart (ViSession instrumentHandle,
                                       ViInt32 scanRange, ViReal64 startFrequency);
ViStatus _VI_FUNC rsesci_GetScanStart (ViSession instrumentHandle,
                                       ViInt32 scanRange, ViReal64* startFrequency);
ViStatus _VI_FUNC rsesci_SetScanStop (ViSession instrumentHandle, ViInt32 scanRange,
                                      ViReal64 stopFrequency);
ViStatus _VI_FUNC rsesci_GetScanStop (ViSession instrumentHandle, ViInt32 scanRange,
                                      ViReal64* stopFrequency);
ViStatus _VI_FUNC rsesci_SetScanStepSize (ViSession instrumentHandle,
                                          ViInt32 scanRange, ViReal64 stepSize);
ViStatus _VI_FUNC rsesci_GetScanStepSize (ViSession instrumentHandle,
                                          ViInt32 scanRange, ViReal64* stepSize);
ViStatus _VI_FUNC rsesci_SetScanBandwidth (ViSession instrumentHandle,
                                           ViInt32 scanRange, ViReal64 bandwidth);
ViStatus _VI_FUNC rsesci_GetScanBandwidth (ViSession instrumentHandle,
                                           ViInt32 scanRange, ViReal64* bandwidth);
ViStatus _VI_FUNC rsesci_SetScanMeasurementTime (ViSession instrumentHandle,
                                                 ViInt32 scanRange,
                                                 ViReal64 measurementTime);
ViStatus _VI_FUNC rsesci_GetScanMeasurementTime (ViSession instrumentHandle,
                                                 ViInt32 scanRange,
                                                 ViReal64* measurementTime);
ViStatus _VI_FUNC rsesci_SetScanAutoRanging (ViSession instrumentHandle,
                                             ViInt32 scanRange,
                                             ViBoolean autoRanging);
ViStatus _VI_FUNC rsesci_GetScanAutoRanging (ViSession instrumentHandle,
                                             ViInt32 scanRange,
                                             ViBoolean* autoRanging);
ViStatus _VI_FUNC rsesci_SetScanRFAttenuation (ViSession instrumentHandle,
                                               ViInt32 scanRange,
                                               ViReal64 attenuation);
ViStatus _VI_FUNC rsesci_GetScanRFAttenuation (ViSession instrumentHandle,
                                               ViInt32 scanRange,
                                               ViReal64* attenuation);
ViStatus _VI_FUNC rsesci_SetScanPreamplifier (ViSession instrumentHandle,
                                              ViInt32 scanRange,
                                              ViBoolean preamplifierState);
ViStatus _VI_FUNC rsesci_GetScanPreamplifier (ViSession instrumentHandle,
                                              ViInt32 scanRange,
                                              ViBoolean* preamplifierState);
ViStatus _VI_FUNC rsesci_SetScanAutoPreamplifier (ViSession instrumentHandle,
                                                  ViInt32 scanRange,
                                                  ViBoolean preamplifierInAutoranging);
ViStatus _VI_FUNC rsesci_GetScanAutoPreamplifier (ViSession instrumentHandle,
                                                  ViInt32 scanRange,
                                                  ViBoolean* preamplifierInAutoranging);
ViStatus _VI_FUNC rsesci_SetScanLowNoisePreamplifierState
             (ViSession instrumentHandle, ViInt32 scanRange,
              ViBoolean lowNoisePreamplifierState);
ViStatus _VI_FUNC rsesci_GetScanLowNoisePreamplifierState
             (ViSession instrumentHandle, ViInt32 scanRange,
              ViBoolean* lowNoisePreamplifierState);
ViStatus _VI_FUNC rsesci_SetScanInput (ViSession instrumentHandle,
                                       ViInt32 scanRange, ViInt32 input);
ViStatus _VI_FUNC rsesci_GetScanInput (ViSession instrumentHandle,
                                       ViInt32 scanRange, ViInt32* input);
ViStatus _VI_FUNC rsesci_SetMarker (ViSession instrumentHandle, ViInt32 window,
                                    ViInt32 marker, ViBoolean state);
ViStatus _VI_FUNC rsesci_GetMarker (ViSession instrumentHandle, ViInt32 window,
                                    ViInt32 marker, ViBoolean* state);
ViStatus _VI_FUNC rsesci_AllMarkersOff (ViSession instrumentHandle, ViInt32 window);
ViStatus _VI_FUNC rsesci_SetMarkerPosition (ViSession instrumentHandle,
                                            ViInt32 window, ViInt32 marker,
                                            ViReal64 x);
ViStatus _VI_FUNC rsesci_GetMarkerPosition (ViSession instrumentHandle,
                                            ViInt32 window, ViInt32 marker,
                                            ViReal64* x);
ViStatus _VI_FUNC rsesci_GetMarkerValue (ViSession instrumentHandle, ViInt32 window,
                                         ViInt32 marker, ViReal64* y);
ViStatus _VI_FUNC rsesci_SetMarkerZoom (ViSession instrumentHandle, ViInt32 window,
                                        ViReal64 zoom);
ViStatus _VI_FUNC rsesci_GetMarkerZoom (ViSession instrumentHandle, ViInt32 window,
                                        ViReal64* zoom);
ViStatus _VI_FUNC rsesci_SetMarkerFrequencyCounter (ViSession instrumentHandle,
                                                    ViInt32 window, ViInt32 marker,
                                                    ViBoolean counterState);
ViStatus _VI_FUNC rsesci_GetMarkerFrequencyCounter (ViSession instrumentHandle,
                                                    ViInt32 window, ViInt32 marker,
                                                    ViBoolean* counterState);
ViStatus _VI_FUNC rsesci_SetMarkerFrequencyCounterResolution
             (ViSession instrumentHandle, ViInt32 window, ViReal64 resolution);
ViStatus _VI_FUNC rsesci_GetMarkerFrequencyCounterResolution
             (ViSession instrumentHandle, ViInt32 window, ViReal64* resolution);
ViStatus _VI_FUNC rsesci_GetMarkerFrequencyCounterValue (ViSession instrumentHandle,
                                                         ViInt32 window,
                                                         ViInt32 marker,
                                                         ViReal64* frequencyCounterValue);
ViStatus _VI_FUNC rsesci_SetDeltaMarker (ViSession instrumentHandle, ViInt32 window,
                                         ViInt32 marker, ViBoolean state);
ViStatus _VI_FUNC rsesci_GetDeltaMarker (ViSession instrumentHandle, ViInt32 window,
                                         ViInt32 marker, ViBoolean* state);
ViStatus _VI_FUNC rsesci_AllDeltaMarkersOff (ViSession instrumentHandle,
                                             ViInt32 window);
ViStatus _VI_FUNC rsesci_SetDeltaMarkerMode (ViSession instrumentHandle,
                                             ViInt32 deltaMarkerMode);
ViStatus _VI_FUNC rsesci_GetDeltaMarkerMode (ViSession instrumentHandle,
                                             ViInt32* deltaMarkerMode);
ViStatus _VI_FUNC rsesci_SetDeltaMarkerPosition (ViSession instrumentHandle,
                                                 ViInt32 window, ViInt32 marker,
                                                 ViReal64 position);
ViStatus _VI_FUNC rsesci_GetDeltaMarkerPosition (ViSession instrumentHandle,
                                                 ViInt32 window, ViInt32 marker,
                                                 ViReal64* position);
ViStatus _VI_FUNC rsesci_GetDeltaMarkerRelativePosition (ViSession instrumentHandle,
                                                         ViInt32 window,
                                                         ViInt32 marker,
                                                         ViReal64* position);
ViStatus _VI_FUNC rsesci_GetDeltaMarkerValue (ViSession instrumentHandle,
                                              ViInt32 window, ViInt32 marker,
                                              ViReal64* y);
ViStatus _VI_FUNC rsesci_SetDeltaMarkerReferenceFixed (ViSession instrumentHandle,
                                                       ViInt32 window,
                                                       ViBoolean fixedReferenceValue);
ViStatus _VI_FUNC rsesci_GetDeltaMarkerReferenceFixed (ViSession instrumentHandle,
                                                       ViInt32 window,
                                                       ViBoolean* fixedReferenceValue);
ViStatus _VI_FUNC rsesci_SetDeltaMarkerReferencePointLevel
             (ViSession instrumentHandle, ViInt32 window,
              ViReal64 referencePointLevel);
ViStatus _VI_FUNC rsesci_GetDeltaMarkerReferencePointLevel
             (ViSession instrumentHandle, ViInt32 window,
              ViReal64* referencePointLevel);
ViStatus _VI_FUNC rsesci_SetDeltaMarkerReferencePointToPeak
             (ViSession instrumentHandle, ViInt32 window);
ViStatus _VI_FUNC rsesci_SetDeltaMarkerReferencePointLevelOffset
             (ViSession instrumentHandle, ViInt32 window, ViReal64 offset);
ViStatus _VI_FUNC rsesci_GetDeltaMarkerReferencePointLevelOffset
             (ViSession instrumentHandle, ViInt32 window, ViReal64* offset);
ViStatus _VI_FUNC rsesci_SetDeltaMarkerReferencePointPosition
             (ViSession instrumentHandle, ViInt32 window, ViReal64 referencePoint);
ViStatus _VI_FUNC rsesci_GetDeltaMarkerReferencePointPosition
             (ViSession instrumentHandle, ViInt32 window, ViReal64* referencePoint);
ViStatus _VI_FUNC rsesci_MarkerSearch (ViSession instrumentHandle, ViInt32 window,
                                       ViInt32 marker, ViInt32 searchMode);
ViStatus _VI_FUNC rsesci_SetAutoMarkerSearch (ViSession instrumentHandle,
                                              ViInt32 window,
                                              ViInt32 autoSearchMode,
                                              ViBoolean autoSearchState);
ViStatus _VI_FUNC rsesci_GetAutoMarkerSearch (ViSession instrumentHandle,
                                              ViInt32 window,
                                              ViInt32 autoSearchMode,
                                              ViBoolean* autoSearchState);
ViStatus _VI_FUNC rsesci_SetMarkerTo (ViSession instrumentHandle, ViInt32 window,
                                      ViInt32 marker, ViInt32 mkrFunction);
ViStatus _VI_FUNC rsesci_SetMarkerToTrace (ViSession instrumentHandle,
                                           ViInt32 window, ViInt32 marker,
                                           ViInt32 trace);
ViStatus _VI_FUNC rsesci_GetMarkerToTrace (ViSession instrumentHandle,
                                           ViInt32 window, ViInt32 marker,
                                           ViInt32* trace);
ViStatus _VI_FUNC rsesci_SetPeakExcursion (ViSession instrumentHandle,
                                           ViInt32 window, ViReal64 peakExcursion);
ViStatus _VI_FUNC rsesci_GetPeakExcursion (ViSession instrumentHandle,
                                           ViInt32 window, ViReal64* peakExcursion);
ViStatus _VI_FUNC rsesci_SetLocalOscillatorSuppression (ViSession instrumentHandle,
                                                        ViBoolean localOscillatorSuppression);
ViStatus _VI_FUNC rsesci_GetLocalOscillatorSuppression (ViSession instrumentHandle,
                                                        ViBoolean* localOscillatorSuppression);
ViStatus _VI_FUNC rsesci_SetMarkerSettingsCoupled (ViSession instrumentHandle,
                                                   ViInt32 window, ViInt32 marker,
                                                   ViBoolean couplingState);
ViStatus _VI_FUNC rsesci_GetMarkerSettingsCoupled (ViSession instrumentHandle,
                                                   ViInt32 window, ViInt32 marker,
                                                   ViBoolean* couplingState);
ViStatus _VI_FUNC rsesci_SetMarkerCoupling (ViSession instrumentHandle,
                                            ViInt32 window,
                                            ViBoolean couplingState);
ViStatus _VI_FUNC rsesci_GetMarkerCoupling (ViSession instrumentHandle,
                                            ViInt32 window,
                                            ViBoolean* couplingState);
ViStatus _VI_FUNC rsesci_DeltaMarkerSearch (ViSession instrumentHandle,
                                            ViInt32 window, ViInt32 marker,
                                            ViInt32 searchMode);
ViStatus _VI_FUNC rsesci_SetDeltaMarkerToTrace (ViSession instrumentHandle,
                                                ViInt32 window, ViInt32 marker,
                                                ViInt32 trace);
ViStatus _VI_FUNC rsesci_GetDeltaMarkerToTrace (ViSession instrumentHandle,
                                                ViInt32 window, ViInt32 marker,
                                                ViInt32* trace);
ViStatus _VI_FUNC rsesci_SetLinkMarkerAndDeltaMarkerState
             (ViSession instrumentHandle, ViInt32 window, ViInt32 marker,
              ViBoolean linkingState);
ViStatus _VI_FUNC rsesci_GetLinkMarkerAndDeltaMarkerState
             (ViSession instrumentHandle, ViInt32 window, ViInt32 marker,
              ViBoolean* linkingState);
ViStatus _VI_FUNC rsesci_SetSearchLimitLines (ViSession instrumentHandle,
                                              ViInt32 window,
                                              ViBoolean limitedRange);
ViStatus _VI_FUNC rsesci_GetSearchLimitLines (ViSession instrumentHandle,
                                              ViInt32 window,
                                              ViBoolean* limitedRange);
ViStatus _VI_FUNC rsesci_SetSearchLeftLimitLine (ViSession instrumentHandle,
                                                 ViInt32 window,
                                                 ViReal64 leftLimit);
ViStatus _VI_FUNC rsesci_GetSearchLeftLimitLine (ViSession instrumentHandle,
                                                 ViInt32 window,
                                                 ViReal64* leftLimit);
ViStatus _VI_FUNC rsesci_SetSearchRightLimitLine (ViSession instrumentHandle,
                                                  ViInt32 window,
                                                  ViReal64 rightLimit);
ViStatus _VI_FUNC rsesci_GetSearchRightLimitLine (ViSession instrumentHandle,
                                                  ViInt32 window,
                                                  ViReal64* rightLimit);
ViStatus _VI_FUNC rsesci_SetSearchThreshold (ViSession instrumentHandle,
                                             ViInt32 window,
                                             ViBoolean searchThreshold);
ViStatus _VI_FUNC rsesci_GetSearchThreshold (ViSession instrumentHandle,
                                             ViInt32 window,
                                             ViBoolean* searchThreshold);
ViStatus _VI_FUNC rsesci_SetSearchThresholdLine (ViSession instrumentHandle,
                                                 ViInt32 window,
                                                 ViReal64 threshold);
ViStatus _VI_FUNC rsesci_GetSearchThresholdLine (ViSession instrumentHandle,
                                                 ViInt32 window,
                                                 ViReal64* threshold);
ViStatus _VI_FUNC rsesci_SetNoiseDensityMeasurement (ViSession instrumentHandle,
                                                     ViInt32 window,
                                                     ViBoolean noiseMeasurement);
ViStatus _VI_FUNC rsesci_GetNoiseDensityMeasurement (ViSession instrumentHandle,
                                                     ViInt32 window,
                                                     ViBoolean* noiseMeasurement);
ViStatus _VI_FUNC rsesci_GetNoiseDensityMeasurementValue (ViSession instrumentHandle,
                                                          ViInt32 window,
                                                          ViReal64* noiseMeasurement);
ViStatus _VI_FUNC rsesci_SetPhaseNoiseMeasurement (ViSession instrumentHandle,
                                                   ViInt32 window,
                                                   ViBoolean phaseNoiseMeasurement);
ViStatus _VI_FUNC rsesci_GetPhaseNoiseMeasurement (ViSession instrumentHandle,
                                                   ViInt32 window,
                                                   ViBoolean* phaseNoiseMeasurement);
ViStatus _VI_FUNC rsesci_SetPhaseNoiseMeasurementAuto (ViSession instrumentHandle,
                                                       ViInt32 window,
                                                       ViBoolean automaticPeakSearch);
ViStatus _VI_FUNC rsesci_GetPhaseNoiseMeasurementAuto (ViSession instrumentHandle,
                                                       ViInt32 window,
                                                       ViBoolean* automaticPeakSearch);
ViStatus _VI_FUNC rsesci_GetPhaseNoiseMeasurementValue (ViSession instrumentHandle,
                                                        ViInt32 window,
                                                        ViReal64* phaseNoiseMeasurement);
ViStatus _VI_FUNC rsesci_SetNdBDown (ViSession instrumentHandle, ViInt32 window,
                                     ViBoolean n_dBDownState);
ViStatus _VI_FUNC rsesci_GetNdBDown (ViSession instrumentHandle, ViInt32 window,
                                     ViBoolean* n_dBDownState);
ViStatus _VI_FUNC rsesci_SetNdBDownLevelSpacing (ViSession instrumentHandle,
                                                 ViInt32 window,
                                                 ViReal64 levelSpacing);
ViStatus _VI_FUNC rsesci_GetNdBDownLevelSpacing (ViSession instrumentHandle,
                                                 ViInt32 window,
                                                 ViReal64* levelSpacing);
ViStatus _VI_FUNC rsesci_GetNdBDownBandwidth (ViSession instrumentHandle,
                                              ViInt32 window,
                                              ViReal64* frequencySpacing);
ViStatus _VI_FUNC rsesci_GetNdBDownFrequencies (ViSession instrumentHandle,
                                                ViInt32 window,
                                                ViReal64 _VI_FAR frequencies[]);
ViStatus _VI_FUNC rsesci_GetNdBDownTimes (ViSession instrumentHandle,
                                          ViInt32 window, ViReal64 _VI_FAR times[]);
ViStatus _VI_FUNC rsesci_SearchForPeakList (ViSession instrumentHandle,
                                            ViInt32 window,
                                            ViInt32 number_of_maxima);

ViStatus _VI_FUNC rsesci_SetPeakListState (ViSession instrumentHandle,
                                           ViInt32 window, ViBoolean state);

ViStatus _VI_FUNC rsesci_GetPeakListState (ViSession instrumentHandle,
                                           ViInt32 window, ViBoolean *state);

ViStatus _VI_FUNC rsesci_SetPeakListAutoSearchState (ViSession instrumentHandle,
                                                     ViInt32 window,
                                                     ViBoolean state);

ViStatus _VI_FUNC rsesci_GetPeakListAutoSearchState (ViSession instrumentHandle,
                                                     ViInt32 window,
                                                     ViBoolean *state);

ViStatus _VI_FUNC rsesci_SetPeakListSortMode (ViSession instrumentHandle,
                                              ViInt32 window, ViInt32 sortMode);
ViStatus _VI_FUNC rsesci_GetPeakListSortMode (ViSession instrumentHandle,
                                              ViInt32 window, ViInt32* sortMode);
ViStatus _VI_FUNC rsesci_GetPeakListCount (ViSession instrumentHandle,
                                           ViInt32 window, ViInt32* peakCount);
ViStatus _VI_FUNC rsesci_GetPeakListXValues (ViSession instrumentHandle,
                                             ViInt32 window,
                                             ViReal64 _VI_FAR xValues[]);
ViStatus _VI_FUNC rsesci_GetPeakListYValues (ViSession instrumentHandle,
                                             ViInt32 window,
                                             ViReal64 _VI_FAR yValues[]);

ViStatus _VI_FUNC rsesci_ReadMarkerPeakList (ViSession instrumentHandle,
                                             ViInt32 trace, ViInt32 noOfValues,
                                             ViReal64 x[], ViReal64 y[],
                                             ViInt32 *returnedValues);

ViStatus _VI_FUNC rsesci_SetMarkerDemodulation (ViSession instrumentHandle,
                                                ViInt32 window, ViInt32 marker,
                                                ViBoolean demodulationState);
ViStatus _VI_FUNC rsesci_GetMarkerDemodulation (ViSession instrumentHandle,
                                                ViInt32 window, ViInt32 marker,
                                                ViBoolean* demodulationState);
ViStatus _VI_FUNC rsesci_SetMarkerDemodulationType (ViSession instrumentHandle,
                                                    ViInt32 demodulationType);
ViStatus _VI_FUNC rsesci_GetMarkerDemodulationType (ViSession instrumentHandle,
                                                    ViInt32* demodulationType);
ViStatus _VI_FUNC rsesci_SetSquelchAnalyzer (ViSession instrumentHandle,
                                             ViInt32 window, ViInt32 marker,
                                             ViBoolean squelchState,
                                             ViReal64 squelchLevel);
ViStatus _VI_FUNC rsesci_GetSquelchAnalyzer (ViSession instrumentHandle,
                                             ViInt32 window, ViInt32 marker,
                                             ViBoolean* squelchState,
                                             ViReal64* squelchLevel);
ViStatus _VI_FUNC rsesci_SetMarkerStopTime (ViSession instrumentHandle,
                                            ViReal64 holdoff);
ViStatus _VI_FUNC rsesci_GetMarkerStopTime (ViSession instrumentHandle,
                                            ViReal64* holdoff);
ViStatus _VI_FUNC rsesci_SetContinuousMarkerDemodulation (ViSession instrumentHandle,
                                                          ViInt32 window,
                                                          ViBoolean continuousDemodulation);
ViStatus _VI_FUNC rsesci_GetContinuousMarkerDemodulation (ViSession instrumentHandle,
                                                          ViInt32 window,
                                                          ViBoolean* continuousDemodulation);
ViStatus _VI_FUNC rsesci_InitiateSpurious (ViSession instrumentHandle,
                                           ViInt32 window);
ViStatus _VI_FUNC rsesci_SetPowerUnit (ViSession instrumentHandle, ViInt32 window,
                                       ViInt32 powerUnit);
ViStatus _VI_FUNC rsesci_GetPowerUnit (ViSession instrumentHandle, ViInt32 window,
                                       ViInt32* powerUnit);
ViStatus _VI_FUNC rsesci_SetTimeDomainPower (ViSession instrumentHandle,
                                             ViInt32 window,
                                             ViInt32 powerMeasurement,
                                             ViBoolean measurementState);
ViStatus _VI_FUNC rsesci_GetTimeDomainPower (ViSession instrumentHandle,
                                             ViInt32 window,
                                             ViInt32 powerMeasurement,
                                             ViBoolean* measurementState);
ViStatus _VI_FUNC rsesci_SetTimeDomainPowerAveraging (ViSession instrumentHandle,
                                                      ViInt32 window,
                                                      ViBoolean averaging);
ViStatus _VI_FUNC rsesci_GetTimeDomainPowerAveraging (ViSession instrumentHandle,
                                                      ViInt32 window,
                                                      ViBoolean* averaging);
ViStatus _VI_FUNC rsesci_SetTimeDomainPowerPeakHold (ViSession instrumentHandle,
                                                     ViInt32 window,
                                                     ViBoolean peakHold);
ViStatus _VI_FUNC rsesci_GetTimeDomainPowerPeakHold (ViSession instrumentHandle,
                                                     ViInt32 window,
                                                     ViBoolean* peakHold);
ViStatus _VI_FUNC rsesci_SetTimeDomainPowerMode (ViSession instrumentHandle,
                                                 ViInt32 window, ViInt32 mode);
ViStatus _VI_FUNC rsesci_GetTimeDomainPowerMode (ViSession instrumentHandle,
                                                 ViInt32 window, ViInt32* mode);
ViStatus _VI_FUNC rsesci_SetTimeDomainPowerReference (ViSession instrumentHandle,
                                                      ViInt32 window);
ViStatus _VI_FUNC rsesci_GetTimeDomainPowerMeanValue (ViSession instrumentHandle,
                                                      ViInt32 window,
                                                      ViInt32 resultType,
                                                      ViReal64* result);
ViStatus _VI_FUNC rsesci_GetTimeDomainPowerPeakValue (ViSession instrumentHandle,
                                                      ViInt32 window,
                                                      ViInt32 resultType,
                                                      ViReal64* result);
ViStatus _VI_FUNC rsesci_GetTimeDomainPowerRMSValue (ViSession instrumentHandle,
                                                     ViInt32 window,
                                                     ViInt32 resultType,
                                                     ViReal64* result);
ViStatus _VI_FUNC rsesci_GetTimeDomainPowerStandardDeviationValue
             (ViSession instrumentHandle, ViInt32 window, ViInt32 resultType,
              ViReal64* result);
ViStatus _VI_FUNC rsesci_GetTimeDomainPowerSignalPulsesValue
             (ViSession instrumentHandle, ViInt32 window,
              ViReal64 time_offset_of_first_pulse, ViReal64 measurementTime,
              ViReal64 period, ViInt32 pulses, ViReal64* result);
ViStatus _VI_FUNC rsesci_SetPowerMeasurement (ViSession instrumentHandle,
                                              ViInt32 window, ViInt32 measurement);
ViStatus _VI_FUNC rsesci_GetPowerMeasurement (ViSession instrumentHandle,
                                              ViInt32 window, ViInt32* measurement);
ViStatus _VI_FUNC rsesci_AdjustPowerMeasurementSetting (ViSession instrumentHandle,
                                                        ViInt32 window,
                                                        ViInt32 measurement);
ViStatus _VI_FUNC rsesci_AdjustReferenceLevel (ViSession instrumentHandle,
                                               ViInt32 window);
ViStatus _VI_FUNC rsesci_GetPowerMeasurementValue (ViSession instrumentHandle,
                                                   ViInt32 window,
                                                   ViInt32 measurement,
                                                   ViInt32 arraySize,
                                                   ViReal64 _VI_FAR result[]);
ViStatus _VI_FUNC rsesci_SetChannelPowerHzMeasurement (ViSession instrumentHandle,
                                                       ViInt32 window,
                                                       ViBoolean relativeResult);
ViStatus _VI_FUNC rsesci_GetChannelPowerHzMeasurement (ViSession instrumentHandle,
                                                       ViInt32 window,
                                                       ViBoolean* relativeResult);
ViStatus _VI_FUNC rsesci_SetPowerMode (ViSession instrumentHandle, ViInt32 window,
                                       ViInt32 powerMode);
ViStatus _VI_FUNC rsesci_GetPowerMode (ViSession instrumentHandle, ViInt32 window,
                                       ViInt32* powerMode);
ViStatus _VI_FUNC rsesci_SetCPACPStandard (ViSession instrumentHandle,
                                           ViInt32 window, ViInt32 standard);
ViStatus _VI_FUNC rsesci_GetCPACPStandard (ViSession instrumentHandle,
                                           ViInt32 window, ViInt32* standard);

ViStatus _VI_FUNC rsesci_SetCPACPUserStandard (ViSession instrumentHandle,
                                               ViInt32 window,
                                               ViString userStandardName);

ViStatus _VI_FUNC rsesci_DeleteACPUserStandard (ViSession instrumentHandle,
                                            ViInt32 window,
                                            ViString standardName);

ViStatus _VI_FUNC rsesci_SaveACPUserStandard (ViSession instrumentHandle,
                                          ViInt32 window, ViString standardName);

ViStatus _VI_FUNC rsesci_SetACPReferenceLevelOffset (ViSession instrumentHandle,
                                                     ViInt32 window,
                                                     ViReal64 referenceLevelOffset);

ViStatus _VI_FUNC rsesci_GetACPReferenceLevelOffset (ViSession instrumentHandle,
                                                     ViInt32 window,
                                                     ViReal64 *referenceLevelOffset);

ViStatus _VI_FUNC rsesci_SetCPReference (ViSession instrumentHandle,
                                         ViInt32 window);
ViStatus _VI_FUNC rsesci_SetNoiseCorrection (ViSession instrumentHandle,
                                             ViInt32 window, ViBoolean correction);
ViStatus _VI_FUNC rsesci_GetNoiseCorrection (ViSession instrumentHandle,
                                             ViInt32 window, ViBoolean* correction);
ViStatus _VI_FUNC rsesci_SetFastACP (ViSession instrumentHandle, ViInt32 window,
                                     ViBoolean fastACP);
ViStatus _VI_FUNC rsesci_GetFastACP (ViSession instrumentHandle, ViInt32 window,
                                     ViBoolean* fastACP);
ViStatus _VI_FUNC rsesci_SetFullSizeDiagram (ViSession instrumentHandle,
                                             ViInt32 size);
ViStatus _VI_FUNC rsesci_GetFullSizeDiagram (ViSession instrumentHandle,
                                             ViInt32* size);
ViStatus _VI_FUNC rsesci_SetNumberAdjacentChannels (ViSession instrumentHandle,
                                                    ViInt32 window,
                                                    ViInt32 number_ofAdjacentChannels);
ViStatus _VI_FUNC rsesci_GetNumberAdjacentChannels (ViSession instrumentHandle,
                                                    ViInt32 window,
                                                    ViInt32* number_ofAdjacentChannels);
ViStatus _VI_FUNC rsesci_SetNumberTXChannels (ViSession instrumentHandle,
                                              ViInt32 window,
                                              ViInt32 number_ofCarriers);
ViStatus _VI_FUNC rsesci_GetNumberTXChannels (ViSession instrumentHandle,
                                              ViInt32 window,
                                              ViInt32* number_ofCarriers);
ViStatus _VI_FUNC rsesci_SetTXACPChannelBandwidth (ViSession instrumentHandle,
                                                   ViInt32 window,
                                                   ViInt32 channelBandwidth,
                                                   ViReal64 channelBandwidthValue);
ViStatus _VI_FUNC rsesci_GetTXACPChannelBandwidth (ViSession instrumentHandle,
                                                   ViInt32 window,
                                                   ViInt32 channelBandwidth,
                                                   ViReal64* channelBandwidthValue);
ViStatus _VI_FUNC rsesci_SetACPChannelSpacing (ViSession instrumentHandle,
                                               ViInt32 window,
                                               ViInt32 channelSpacing,
                                               ViReal64 channelSpacingValue);
ViStatus _VI_FUNC rsesci_GetACPChannelSpacing (ViSession instrumentHandle,
                                               ViInt32 window,
                                               ViInt32 channelSpacing,
                                               ViReal64* channelSpacingValue);
ViStatus _VI_FUNC rsesci_SetACPReferenceChannel (ViSession instrumentHandle,
                                                 ViInt32 window,
                                                 ViInt32 ACPReferenceChannel);
ViStatus _VI_FUNC rsesci_SetCPACPPowerMeasurementMode (ViSession instrumentHandle,
                                                       ViInt32 window,
                                                       ViInt32 mode);
ViStatus _VI_FUNC rsesci_GetCPACPPowerMeasurementMode (ViSession instrumentHandle,
                                                       ViInt32 window,
                                                       ViInt32* mode);
ViStatus _VI_FUNC rsesci_SetCPACPMeasurementTrace (ViSession instrumentHandle,
                                                   ViInt32 window, ViInt32 trace);
ViStatus _VI_FUNC rsesci_GetCPACPMeasurementTrace (ViSession instrumentHandle,
                                                   ViInt32 window, ViInt32* trace);

ViStatus _VI_FUNC rsesci_SetAllACPWeigthingFilterState (ViSession instrumentHandle,
                                                        ViInt32 window,
                                                        ViBoolean weightingFilterState);

ViStatus _VI_FUNC rsesci_SetAllACPWeightingFilterFactor (ViSession instrumentHandle,
                                                         ViInt32 window,
                                                         ViReal64 rolloffFactor);

ViStatus _VI_FUNC rsesci_SetACPWeightingFilterState (ViSession instrumentHandle,
                                                     ViInt32 window,
                                                     ViInt32 channel,
                                                     ViBoolean weightingFilterState);

ViStatus _VI_FUNC rsesci_GetACPWeightingFilterState (ViSession instrumentHandle,
                                                     ViInt32 window,
                                                     ViInt32 channel,
                                                     ViBoolean *weightingFilterState);

ViStatus _VI_FUNC rsesci_SetACPWeightingFilterFactor (ViSession instrumentHandle,
                                                      ViInt32 window,
                                                      ViInt32 channel,
                                                      ViReal64 rolloffFactor);

ViStatus _VI_FUNC rsesci_GetACPWeightingFilterFactor (ViSession instrumentHandle,
                                                      ViInt32 window,
                                                      ViInt32 channel,
                                                      ViReal64 *rolloffFactor);

ViStatus _VI_FUNC rsesci_SetACPLimitChecking (ViSession instrumentHandle,
                                              ViInt32 window,
                                              ViBoolean limitChecking);
ViStatus _VI_FUNC rsesci_GetACPLimitChecking (ViSession instrumentHandle,
                                              ViInt32 window,
                                              ViBoolean* limitChecking);
ViStatus _VI_FUNC rsesci_SetACPLimits (ViSession instrumentHandle, ViInt32 window,
                                       ViInt32 limitType, ViInt32 mode,
                                       ViBoolean state, ViReal64 limitValue);
ViStatus _VI_FUNC rsesci_GetACPLimits (ViSession instrumentHandle, ViInt32 window,
                                       ViInt32 mode, ViInt32 limitType,
                                       ViBoolean* state, ViReal64* limitValue);
ViStatus _VI_FUNC rsesci_GetACPLimitCheckingResult (ViSession instrumentHandle,
                                                    ViInt32 window,
                                                    ViInt32 limitType,
                                                    ViBoolean* result);
ViStatus _VI_FUNC rsesci_SetPowerBandwidthPercentage (ViSession instrumentHandle,
                                                      ViInt32 window,
                                                      ViReal64 percentage);
ViStatus _VI_FUNC rsesci_GetPowerBandwidthPercentage (ViSession instrumentHandle,
                                                      ViInt32 window,
                                                      ViReal64* percentage);
ViStatus _VI_FUNC rsesci_SetChannelBandwidth (ViSession instrumentHandle,
                                              ViInt32 window,
                                              ViReal64 channelBandwidth);
ViStatus _VI_FUNC rsesci_GetChannelBandwidth (ViSession instrumentHandle,
                                              ViInt32 window,
                                              ViReal64* channelBandwidth);
ViStatus _VI_FUNC rsesci_SetSignalAmplitudeStatistics (ViSession instrumentHandle,
                                                       ViInt32 measurement);
ViStatus _VI_FUNC rsesci_GetSignalAmplitudeStatistics (ViSession instrumentHandle,
                                                       ViInt32* measurement);
ViStatus _VI_FUNC rsesci_SetCCDFPercentMarker (ViSession instrumentHandle,
                                               ViInt32 window, ViInt32 marker,
                                               ViReal64 position);
ViStatus _VI_FUNC rsesci_GetCCDFPercentMarker (ViSession instrumentHandle,
                                               ViInt32 window, ViInt32 marker,
                                               ViReal64* position);
ViStatus _VI_FUNC rsesci_SetStatisticsNumberSamples (ViSession instrumentHandle,
                                                     ViReal64 numberOfSamples);
ViStatus _VI_FUNC rsesci_GetStatisticsNumberSamples (ViSession instrumentHandle,
                                                     ViReal64* numberOfSamples);
ViStatus _VI_FUNC rsesci_StatisticsAdjustSettings (ViSession instrumentHandle);
ViStatus _VI_FUNC rsesci_StatisticsDefaultSettings (ViSession instrumentHandle);
ViStatus _VI_FUNC rsesci_GetStatisticalMeasurementsResults
             (ViSession instrumentHandle, ViInt32 trace, ViInt32 resultType,
              ViReal64 _VI_FAR result[]);
ViStatus _VI_FUNC rsesci_QuerySignalStatisticCCDFLevel (ViSession instrumentHandle,
                                                        ViInt32 trace,
                                                        ViInt32 probability,
                                                        ViReal64* result);
ViStatus _VI_FUNC rsesci_SetStatisticsXAxisReferenceLevel
             (ViSession instrumentHandle, ViReal64 referenceLevel);
ViStatus _VI_FUNC rsesci_GetStatisticsXAxisReferenceLevel
             (ViSession instrumentHandle, ViReal64* referenceLevel);
ViStatus _VI_FUNC rsesci_SetStatisticsXAxisRange (ViSession instrumentHandle,
                                                  ViReal64 range);
ViStatus _VI_FUNC rsesci_GetStatisticsXAxisRange (ViSession instrumentHandle,
                                                  ViReal64* range);
ViStatus _VI_FUNC rsesci_SetStatisticsYAxisMinValue (ViSession instrumentHandle,
                                                     ViReal64 minValue);
ViStatus _VI_FUNC rsesci_GetStatisticsYAxisMinValue (ViSession instrumentHandle,
                                                     ViReal64* minValue);
ViStatus _VI_FUNC rsesci_SetStatisticsYAxisMaxValue (ViSession instrumentHandle,
                                                     ViReal64 maxValue);
ViStatus _VI_FUNC rsesci_GetStatisticsYAxisMaxValue (ViSession instrumentHandle,
                                                     ViReal64* maxValue);
ViStatus _VI_FUNC rsesci_SetStatisticsYAxisUnit (ViSession instrumentHandle,
                                                 ViInt32 units);
ViStatus _VI_FUNC rsesci_GetStatisticsYAxisUnit (ViSession instrumentHandle,
                                                 ViInt32* units);
ViStatus _VI_FUNC rsesci_SetModulationDepthMeasurement (ViSession instrumentHandle,
                                                        ViInt32 window,
                                                        ViBoolean modulationDepthMeasurement);
ViStatus _VI_FUNC rsesci_GetModulationDepthMeasurement (ViSession instrumentHandle,
                                                        ViInt32 window,
                                                        ViBoolean* modulationDepthMeasurement);
ViStatus _VI_FUNC rsesci_GetModulationDepthMeasurementValue
             (ViSession instrumentHandle, ViInt32 window, ViReal64* result);

ViStatus _VI_FUNC rsesci_SetThirdOrderInterceptFunction (ViSession instrumentHandle,
                                                         ViInt32 window,
                                                         ViInt32 TOIMarker);

ViStatus _VI_FUNC rsesci_GetThirdOrderInterceptFunction (ViSession instrumentHandle,
                                                         ViInt32 window,
                                                         ViInt32 *TOIMarker);

ViStatus _VI_FUNC rsesci_SetThirdOrderInterceptMeasurement
             (ViSession instrumentHandle, ViInt32 window, ViBoolean state);
ViStatus _VI_FUNC rsesci_GetThirdOrderInterceptMeasurement
             (ViSession instrumentHandle, ViInt32 window, ViBoolean* state);
ViStatus _VI_FUNC rsesci_GetThirdOrderInterceptMeasurementValue
             (ViSession instrumentHandle, ViInt32 window, ViReal64* TOIResult);
ViStatus _VI_FUNC rsesci_SetMultiplePowerMeasurementParameters
             (ViSession instrumentHandle, ViInt32 window, ViBoolean peakDetector,
              ViBoolean RMSDetector, ViBoolean averageDetector, ViInt32 triggerMode,
              ViInt32 triggerSlope, ViReal64 triggerOffset, ViReal64 gateLength);
ViStatus _VI_FUNC rsesci_GetMultiplePowerMeasurementParameters
             (ViSession instrumentHandle, ViInt32 window, ViBoolean* peakDetector,
              ViBoolean* RMSDetector, ViBoolean* averageDetector,
              ViInt32* triggerMode, ViInt32* triggerSlope, ViReal64* triggerOffset,
              ViReal64* gateLength);
ViStatus _VI_FUNC rsesci_MultiplePowerMeasurementSequence
             (ViSession instrumentHandle, ViInt32 window, ViInt32 number_ofEntries,
              ViReal64 _VI_FAR analyzerFrequency[],
              ViReal64 _VI_FAR referenceLevel[],
              ViReal64 _VI_FAR RFInputAttenuation[], ViInt32 _VI_FAR filterType[],
              ViReal64 _VI_FAR resolutionBandwidth[],
              ViReal64 _VI_FAR videoBandwidth[], ViReal64 _VI_FAR measurementTime[],
              ViReal64 _VI_FAR triggerLevel[]);
ViStatus _VI_FUNC rsesci_MultiplePowerMeasurementResults (ViSession instrumentHandle,
                                                          ViInt32 window,
                                                          ViInt32* number_ofResults,
                                                          ViReal64 _VI_FAR powerMeasurementResults[]);
ViStatus _VI_FUNC rsesci_SetMultiplePowerMeasurementAveraging
             (ViSession instrumentHandle, ViInt32 window, ViInt32 averaging);
ViStatus _VI_FUNC rsesci_GetMultiplePowerMeasurementAveraging
             (ViSession instrumentHandle, ViInt32 window, ViInt32* averaging);
ViStatus _VI_FUNC rsesci_DeactivateMultiplePowerMeasurement
             (ViSession instrumentHandle, ViInt32 window);
ViStatus _VI_FUNC rsesci_MultipleBurstPowerMeasurementSequence
             (ViSession instrumentHandle, ViInt32 window,
              ViReal64 analyzerFrequency, ViReal64 resolutionBandwidth,
              ViReal64 measurementTime, ViInt32 triggerSource,
              ViReal64 triggerLevel, ViReal64 triggerOffset,
              ViInt32 measurementType, ViInt32 no_ofMeasurements);
ViStatus _VI_FUNC rsesci_MultipleBurstPowerMeasurementResult
             (ViSession instrumentHandle, ViInt32 window,
              ViReal64 _VI_FAR powerMeasurementResults[],
              ViInt32* number_ofResults);
ViStatus _VI_FUNC rsesci_MultipleBurstPowerMeasurementResultMinimum
             (ViSession instrumentHandle, ViInt32 window,
              ViReal64* powerMeasurementResult);
ViStatus _VI_FUNC rsesci_SetHDistState (ViSession instrumentHandle,
                                        ViBoolean state);
ViStatus _VI_FUNC rsesci_GetHDistState (ViSession instrumentHandle,
                                        ViBoolean* state);
ViStatus _VI_FUNC rsesci_SetNumberOfHDist (ViSession instrumentHandle,
                                           ViInt32 no_ofHarmonics);
ViStatus _VI_FUNC rsesci_GetNumberOfHDist (ViSession instrumentHandle,
                                           ViInt32* no_ofHarmonics);
ViStatus _VI_FUNC rsesci_SetHDistBandwidthState (ViSession instrumentHandle,
                                                 ViBoolean harmonicRBWAuto);
ViStatus _VI_FUNC rsesci_GetHDistBandwidthState (ViSession instrumentHandle,
                                                 ViBoolean* harmonicRBWAuto);
ViStatus _VI_FUNC rsesci_AdjustHDistSettings (ViSession instrumentHandle);
ViStatus _VI_FUNC rsesci_GetHDist (ViSession instrumentHandle,
                                   ViReal64* harmonicDistortion_in_percent,
                                   ViReal64* harmonicDistortion_in_dB);
ViStatus _VI_FUNC rsesci_GetHDistHarmonicsList (ViSession instrumentHandle,
                                                ViReal64 _VI_FAR harmonicsList[]);

ViStatus _VI_FUNC rsesci_GetHDistBandwidthResolution (ViSession instrumentHandle,
                                                         ViInt32 arraySize,
                                                         ViReal64 resolutionBandwidthValue[]);

ViStatus _VI_FUNC rsesci_SetSEMode (ViSession instrumentHandle, ViInt32 mode);
ViStatus _VI_FUNC rsesci_GetSEMode (ViSession instrumentHandle, ViInt32* mode);
ViStatus _VI_FUNC rsesci_ConfigureSESweepRange (ViSession instrumentHandle,
                                                ViInt32 range,
                                                ViReal64 startFrequency,
                                                ViReal64 stopFrequency,
                                                ViInt32 filter,
                                                ViReal64 resolutionBandwidth,
                                                ViReal64 videoBandwidth,
                                                ViBoolean sweepTimeAuto,
                                                ViReal64 sweepTime,
                                                ViInt32 detector,
                                                ViReal64 refLevelValue,
                                                ViBoolean attenuatorAuto,
                                                ViReal64 manualAttenuatorValuedB,
                                                ViInt32 sweepPoints,
                                                ViBoolean stopAfterSweep,
                                                ViString transducerFactor);
ViStatus _VI_FUNC rsesci_SetSEPreamplifierState (ViSession instrumentHandle,
                                                 ViInt32 range,
                                                 ViBoolean preamplifier);
ViStatus _VI_FUNC rsesci_GetSEPreamplifierState (ViSession instrumentHandle,
                                                 ViInt32 range,
                                                 ViBoolean* preamplifier);
ViStatus _VI_FUNC rsesci_SEDeleteRange (ViSession instrumentHandle, ViInt32 range);
ViStatus _VI_FUNC rsesci_StoreSEToFile (ViSession instrumentHandle,
                                        ViString fileName);

ViStatus _VI_FUNC rsesci_LoadSEConfiguration (ViSession instrumentHandle,
                                              ViString fileName);

ViStatus _VI_FUNC rsesci_SaveSEConfiguration (ViSession instrumentHandle,
                                              ViString fileName);

ViStatus _VI_FUNC rsesci_DeleteSEConfiguration (ViSession instrumentHandle,
                                                ViString fileName);

ViStatus _VI_FUNC rsesci_SpuriousEmissionsConfigurationCatalog (ViSession instrumentHandle,
                                                                ViInt32 bufferSize,
                                                                ViChar catalog[]);

ViStatus _VI_FUNC rsesci_ReadSEPeakList (ViSession instrumentHandle, ViInt32 trace,
                                         ViInt32 noOfValues,
                                         ViReal64 _VI_FAR frequency[],
                                         ViReal64 _VI_FAR level[],
                                         ViReal64 _VI_FAR deltaLimit[],
                                         ViInt32* returnedValues);
ViStatus _VI_FUNC rsesci_SetSESweepStart (ViSession instrumentHandle, ViInt32 range,
                                          ViReal64 startFrequency);
ViStatus _VI_FUNC rsesci_GetSESweepStart (ViSession instrumentHandle, ViInt32 range,
                                          ViReal64* startFrequency);
ViStatus _VI_FUNC rsesci_SetSESweepStop (ViSession instrumentHandle, ViInt32 range,
                                         ViReal64 stopFrequency);
ViStatus _VI_FUNC rsesci_GetSESweepStop (ViSession instrumentHandle, ViInt32 range,
                                         ViReal64* stopFrequency);
ViStatus _VI_FUNC rsesci_SetSESweepFilter (ViSession instrumentHandle,
                                           ViInt32 range, ViInt32 filter);
ViStatus _VI_FUNC rsesci_GetSESweepFilter (ViSession instrumentHandle,
                                           ViInt32 range, ViInt32* filter);
ViStatus _VI_FUNC rsesci_SetSESweepRBW (ViSession instrumentHandle, ViInt32 range,
                                        ViReal64 resolutionBandwidth);
ViStatus _VI_FUNC rsesci_GetSESweepRBW (ViSession instrumentHandle, ViInt32 range,
                                        ViReal64* resolutionBandwidth);
ViStatus _VI_FUNC rsesci_SetSESweepVBW (ViSession instrumentHandle, ViInt32 range,
                                        ViReal64 videoBandwidth);
ViStatus _VI_FUNC rsesci_GetSESweepVBW (ViSession instrumentHandle, ViInt32 range,
                                        ViReal64* videoBandwidth);
ViStatus _VI_FUNC rsesci_SetSESweepTimeAuto (ViSession instrumentHandle,
                                             ViInt32 range,
                                             ViBoolean sweepTimeAuto);
ViStatus _VI_FUNC rsesci_GetSESweepTimeAuto (ViSession instrumentHandle,
                                             ViInt32 range,
                                             ViBoolean* sweepTimeAuto);
ViStatus _VI_FUNC rsesci_SetSESweepTime (ViSession instrumentHandle, ViInt32 range,
                                         ViReal64 sweepTime);
ViStatus _VI_FUNC rsesci_GetSESweepTime (ViSession instrumentHandle, ViInt32 range,
                                         ViReal64* sweepTime);
ViStatus _VI_FUNC rsesci_SetSESweepDetector (ViSession instrumentHandle,
                                             ViInt32 range, ViInt32 detector);
ViStatus _VI_FUNC rsesci_GetSESweepDetector (ViSession instrumentHandle,
                                             ViInt32 range, ViInt32* detector);
ViStatus _VI_FUNC rsesci_SetSESweepRefLevel (ViSession instrumentHandle,
                                             ViInt32 range, ViReal64 refLevelValue);
ViStatus _VI_FUNC rsesci_GetSESweepRefLevel (ViSession instrumentHandle,
                                             ViInt32 range,
                                             ViReal64* refLevelValue);
ViStatus _VI_FUNC rsesci_SetSESweepAttenuatorAuto (ViSession instrumentHandle,
                                                   ViInt32 range,
                                                   ViBoolean attenuatorAuto);
ViStatus _VI_FUNC rsesci_GetSESweepAttenuatorAuto (ViSession instrumentHandle,
                                                   ViInt32 range,
                                                   ViBoolean* attenuatorAuto);
ViStatus _VI_FUNC rsesci_SetSESweepAttenuatorValue (ViSession instrumentHandle,
                                                    ViInt32 range,
                                                    ViReal64 manualAttenuatorValuedB);
ViStatus _VI_FUNC rsesci_GetSESweepAttenuatorValue (ViSession instrumentHandle,
                                                    ViInt32 range,
                                                    ViReal64* manualAttenuatorValuedB);
ViStatus _VI_FUNC rsesci_SetSESweepPoints (ViSession instrumentHandle,
                                           ViInt32 range, ViInt32 sweepPoints);
ViStatus _VI_FUNC rsesci_GetSESweepPoints (ViSession instrumentHandle,
                                           ViInt32 range, ViInt32* sweepPoints);
ViStatus _VI_FUNC rsesci_SetSESweepStopAfterSweep (ViSession instrumentHandle,
                                                   ViInt32 range,
                                                   ViBoolean stopAfterSweep);
ViStatus _VI_FUNC rsesci_GetSESweepStopAfterSweep (ViSession instrumentHandle,
                                                   ViInt32 range,
                                                   ViBoolean* stopAfterSweep);
ViStatus _VI_FUNC rsesci_SetSESweepTransducerFactor (ViSession instrumentHandle,
                                                     ViInt32 range,
                                                     ViString transducerFactor);
ViStatus _VI_FUNC rsesci_GetSESweepTransducerFactor (ViSession instrumentHandle,
                                                     ViInt32 range,
                                                     ViInt32 arraySize,
                                                     ViChar _VI_FAR transducerFactor[]);
ViStatus _VI_FUNC rsesci_SetSESweepLimit (ViSession instrumentHandle, ViInt32 range,
                                          ViReal64 limitValue);
ViStatus _VI_FUNC rsesci_GetSESweepLimit (ViSession instrumentHandle, ViInt32 range,
                                          ViReal64* limitValue);
ViStatus _VI_FUNC rsesci_SetSESweepLimitState (ViSession instrumentHandle,
                                               ViBoolean limitState);
ViStatus _VI_FUNC rsesci_GetSESweepLimitState (ViSession instrumentHandle,
                                               ViBoolean* limitState);
ViStatus _VI_FUNC rsesci_GetSENumberOfListRanges (ViSession instrumentHandle,
                                                  ViInt32* numberOfRanges);
ViStatus _VI_FUNC rsesci_InitiateFinalMeasurementTest (ViSession instrumentHandle,
                                                       ViInt32 window);
ViStatus _VI_FUNC rsesci_InitiateEMITest (ViSession instrumentHandle,
                                          ViInt32 window);
ViStatus _VI_FUNC rsesci_SetReceiverDetector (ViSession instrumentHandle,
                                              ViInt32 window, ViBoolean maxPeak,
                                              ViBoolean minPeak, ViBoolean RMS,
                                              ViBoolean average,
                                              ViBoolean quasipeak,
                                              ViBoolean CISPRAverage);
ViStatus _VI_FUNC rsesci_GetReceiverDetector (ViSession instrumentHandle,
                                              ViInt32 window, ViBoolean* maxPeak,
                                              ViBoolean* minPeak, ViBoolean* RMS,
                                              ViBoolean* average,
                                              ViBoolean* quasipeak,
                                              ViBoolean* CISPRAverage);
ViStatus _VI_FUNC rsesci_SetReceiverDetectorWithCRMS (ViSession instrumentHandle,
                                                      ViInt32 window,
                                                      ViBoolean maxPeak,
                                                      ViBoolean minPeak,
                                                      ViBoolean RMS,
                                                      ViBoolean average,
                                                      ViBoolean quasipeak,
                                                      ViBoolean CISPRAverage,
                                                      ViBoolean CISPRRMS);
ViStatus _VI_FUNC rsesci_GetReceiverDetectorWithCRMS (ViSession instrumentHandle,
                                                      ViInt32 window,
                                                      ViBoolean* maxPeak,
                                                      ViBoolean* minPeak,
                                                      ViBoolean* RMS,
                                                      ViBoolean* average,
                                                      ViBoolean* quasipeak,
                                                      ViBoolean* CISPRAverage,
                                                      ViBoolean* CISPRRMS);
ViStatus _VI_FUNC rsesci_SetFinalReceiverDetector (ViSession instrumentHandle,
                                                   ViInt32 window, ViInt32 trace,
                                                   ViInt32 finalDetector);
ViStatus _VI_FUNC rsesci_GetFinalReceiverDetector (ViSession instrumentHandle,
                                                   ViInt32 window, ViInt32 trace,
                                                   ViInt32* finalDetector);
ViStatus _VI_FUNC rsesci_PeakSearch (ViSession instrumentHandle);
ViStatus _VI_FUNC rsesci_SetPeakSearchAuto (ViSession instrumentHandle,
                                            ViBoolean peakSearchAuto);
ViStatus _VI_FUNC rsesci_GetPeakSearchAuto (ViSession instrumentHandle,
                                            ViBoolean* peakSearchAuto);
ViStatus _VI_FUNC rsesci_SetPeakSearchAddition (ViSession instrumentHandle,
                                                ViInt32 window,
                                                ViReal64 frequencyAddition);
ViStatus _VI_FUNC rsesci_SetPeakSearchMethod (ViSession instrumentHandle,
                                              ViInt32 searchMethod);
ViStatus _VI_FUNC rsesci_GetPeakSearchMethod (ViSession instrumentHandle,
                                              ViInt32* searchMethod);
ViStatus _VI_FUNC rsesci_SetPeakSearchMargin (ViSession instrumentHandle,
                                              ViReal64 margin);
ViStatus _VI_FUNC rsesci_GetPeakSearchMargin (ViSession instrumentHandle,
                                              ViReal64* margin);
ViStatus _VI_FUNC rsesci_SetPeakSearchSubranges (ViSession instrumentHandle,
                                                 ViInt32 subranges);
ViStatus _VI_FUNC rsesci_GetPeakSearchSubranges (ViSession instrumentHandle,
                                                 ViInt32* subranges);
ViStatus _VI_FUNC rsesci_SetPeakSearchListDisplay (ViSession instrumentHandle,
                                                   ViInt32 window, ViInt32 trace,
                                                   ViInt32 indication);
ViStatus _VI_FUNC rsesci_GetPeakSearchListDisplay (ViSession instrumentHandle,
                                                   ViInt32 window, ViInt32 trace,
                                                   ViInt32* indication);
ViStatus _VI_FUNC rsesci_ClearPeakSearchList (ViSession instrumentHandle,
                                              ViInt32 window);
ViStatus _VI_FUNC rsesci_SetThresholdScan (ViSession instrumentHandle,
                                           ViInt32 window, ViBoolean thresholdScan);
ViStatus _VI_FUNC rsesci_GetThresholdScan (ViSession instrumentHandle,
                                           ViInt32 window,
                                           ViBoolean* thresholdScan);
ViStatus _VI_FUNC rsesci_SetNBBBDiscrimination (ViSession instrumentHandle,
                                                ViInt32 window,
                                                ViBoolean discriminationState);
ViStatus _VI_FUNC rsesci_GetNBBBDiscrimination (ViSession instrumentHandle,
                                                ViInt32 window,
                                                ViBoolean* discriminationState);
ViStatus _VI_FUNC rsesci_SetNBBBDiscriminationValue (ViSession instrumentHandle,
                                                     ViInt32 window,
                                                     ViReal64 discriminationThreshold);
ViStatus _VI_FUNC rsesci_GetNBBBDiscriminationValue (ViSession instrumentHandle,
                                                     ViInt32 window,
                                                     ViReal64* discriminationThreshold);
ViStatus _VI_FUNC rsesci_SetFinalMeasurementTime (ViSession instrumentHandle,
                                                  ViInt32 window,
                                                  ViReal64 measurementTime);
ViStatus _VI_FUNC rsesci_GetFinalMeasurementTime (ViSession instrumentHandle,
                                                  ViInt32 window,
                                                  ViReal64* measurementTime);
ViStatus _VI_FUNC rsesci_SetFinalMeasurementAuto (ViSession instrumentHandle,
                                                  ViInt32 window,
                                                  ViBoolean automaticMeasurement);
ViStatus _VI_FUNC rsesci_GetFinalMeasurementAuto (ViSession instrumentHandle,
                                                  ViInt32 window,
                                                  ViBoolean* automaticMeasurement);
ViStatus _VI_FUNC rsesci_SetVnetworkType (ViSession instrumentHandle,
                                          ViInt32 window, ViInt32 measurement,
                                          ViInt32 vnetwork);
ViStatus _VI_FUNC rsesci_GetVnetworkType (ViSession instrumentHandle,
                                          ViInt32 window, ViInt32 measurement,
                                          ViInt32* vnetwork);
ViStatus _VI_FUNC rsesci_SetVnetworkProtectionEarth (ViSession instrumentHandle,
                                                     ViInt32 window,
                                                     ViInt32 measurement,
                                                     ViInt32 protectiveEarth);
ViStatus _VI_FUNC rsesci_GetVnetworkProtectionEarth (ViSession instrumentHandle,
                                                     ViInt32 window,
                                                     ViInt32 measurement,
                                                     ViInt32* protectiveEarth);
ViStatus _VI_FUNC rsesci_SetVnetworkProtectionEarthFinalMeasurement
             (ViSession instrumentHandle, ViInt32 window,
              ViInt32 numberOfProtectives, ViInt32 _VI_FAR protectiveEarth[]);
ViStatus _VI_FUNC rsesci_GetVnetworkProtectionEarthFinalMeasurement
             (ViSession instrumentHandle, ViInt32 window,
              ViInt32* numberOfProtectives, ViInt32 _VI_FAR protectiveEarth[]);
ViStatus _VI_FUNC rsesci_SetVnetworkPhase (ViSession instrumentHandle,
                                           ViInt32 window, ViInt32 measurement,
                                           ViInt32 phase);
ViStatus _VI_FUNC rsesci_GetVnetworkPhase (ViSession instrumentHandle,
                                           ViInt32 window, ViInt32 measurement,
                                           ViInt32* phase);
ViStatus _VI_FUNC rsesci_SetVnetworkPhaseFinalMeasurement
             (ViSession instrumentHandle, ViInt32 window, ViInt32 numberOfPhases,
              ViInt32 _VI_FAR phases[]);
ViStatus _VI_FUNC rsesci_GetVnetworkPhaseFinalMeasurement
             (ViSession instrumentHandle, ViInt32 window, ViInt32* numberOfPhases,
              ViInt32 _VI_FAR phases[]);
ViStatus _VI_FUNC rsesci_SetVnetworkHighPass (ViSession instrumentHandle,
                                              ViInt32 window, ViInt32 measurement,
                                              ViBoolean phase);
ViStatus _VI_FUNC rsesci_GetVnetworkHighPass (ViSession instrumentHandle,
                                              ViInt32 window, ViInt32 measurement,
                                              ViBoolean* phase);
ViStatus _VI_FUNC rsesci_SetDemodulationType (ViSession instrumentHandle,
                                              ViInt32 window, ViInt32 demodulation);
ViStatus _VI_FUNC rsesci_GetDemodulationType (ViSession instrumentHandle,
                                              ViInt32 window,
                                              ViInt32* demodulation);
ViStatus _VI_FUNC rsesci_SetSquelchReceiver (ViSession instrumentHandle,
                                             ViInt32 window, ViBoolean squelchState,
                                             ViReal64 squelchLevel);
ViStatus _VI_FUNC rsesci_GetSquelchReceiver (ViSession instrumentHandle,
                                             ViInt32 window,
                                             ViBoolean* squelchState,
                                             ViReal64* squelchLevel);
ViStatus _VI_FUNC rsesci_ReadReceiverDetector (ViSession instrumentHandle,
                                               ViReal64* firstDetector,
                                               ViReal64* secondDetector,
                                               ViReal64* thirdDetector);
ViStatus _VI_FUNC rsesci_ReadReceiverDetectorPeakHold (ViSession instrumentHandle,
                                                       ViReal64 _VI_FAR firstDetector[],
                                                       ViReal64 _VI_FAR secondDetector[],
                                                       ViReal64 _VI_FAR thirdDetector[]);
ViStatus _VI_FUNC rsesci_ReadScanMeasurement (ViSession instrumentHandle,
                                              ViInt32 arraySize,
                                              ViInt32* traceStatus,
                                              ViInt32* number_ofResults,
                                              ViChar _VI_FAR statusData[],
                                              ViReal64 _VI_FAR results_ofTrace1[],
                                              ViReal64 _VI_FAR results_ofTrace2[],
                                              ViReal64 _VI_FAR results_ofTrace3[]);
ViStatus _VI_FUNC rsesci_ReadScanMeasurementStatus (ViSession instrumentHandle,
                                                    ViInt32 arraySize,
                                                    ViInt32* number_ofResults,
                                                    ViChar _VI_FAR statusData[]);
ViStatus _VI_FUNC rsesci_ReadFinalMeasurement (ViSession instrumentHandle,
                                               ViInt32 trace, ViInt32 arraySize,
                                               ViInt32* number_ofResults,
                                               ViReal64 _VI_FAR frequency[],
                                               ViReal64 _VI_FAR level[],
                                               ViReal64 _VI_FAR deltaLimit[]);
ViStatus _VI_FUNC rsesci_ReadAdditionalMeasurementData (ViSession instrumentHandle,
                                                        ViInt32 window,
                                                        ViInt32 trace,
                                                        ViInt32 arrayLength,
                                                        ViInt32* actualPoints,
                                                        ViReal64 _VI_FAR values[]);
ViStatus _VI_FUNC rsesci_GetCurrentResults (ViSession instrumentHandle,
                                            ViInt32 window, ViReal64* xValue,
                                            ViReal64* yValue);
ViStatus _VI_FUNC rsesci_GetCurrentYResult (ViSession instrumentHandle,
                                            ViInt32 window, ViReal64* level);

ViStatus _VI_FUNC rsesci_SetChannelList (ViSession instrumentHandle,
                                         ViInt32 noOfValues, ViInt32 scanTable,
                                         ViInt32 channelList[]);

ViStatus _VI_FUNC rsesci_GetChannelList (ViSession instrumentHandle,
                                         ViInt32 arraySize, ViInt32 scanTable,
                                         ViInt32 channelList[],
                                         ViInt32 *returnedValues);

ViStatus _VI_FUNC rsesci_SetChannelListScan (ViSession instrumentHandle,
                                             ViInt32 scanTable, ViBoolean scan);

ViStatus _VI_FUNC rsesci_GetChannelListScan (ViSession instrumentHandle,
                                             ViInt32 scanTable, ViBoolean *scan);

ViStatus _VI_FUNC rsesci_SetChannelListStore (ViSession instrumentHandle,
                                              ViBoolean store);

ViStatus _VI_FUNC rsesci_GetChannelListStore (ViSession instrumentHandle,
                                              ViBoolean *store);

ViStatus _VI_FUNC rsesci_SetTraceSingle (ViSession instrumentHandle,
                                         ViInt32 value);

ViStatus _VI_FUNC rsesci_GetTraceSingle (ViSession instrumentHandle,
                                         ViInt32 *value);

ViStatus _VI_FUNC rsesci_SetTraceScan (ViSession instrumentHandle, ViInt32 value);

ViStatus _VI_FUNC rsesci_GetTraceScan (ViSession instrumentHandle,
                                       ViInt32 *value);

ViStatus _VI_FUNC rsesci_SetInstrumentMode (ViSession instrumentHandle,
                                            ViInt32 instrumentMode);
ViStatus _VI_FUNC rsesci_GetInstrumentMode (ViSession instrumentHandle,
                                            ViInt32* instrumentMode);
ViStatus _VI_FUNC rsesci_SetMixedInstrumentMode (ViSession instrumentHandle,
                                                 ViBoolean mixedMode,
                                                 ViInt32 screens);
ViStatus _VI_FUNC rsesci_GetMixedInstrumentMode (ViSession instrumentHandle,
                                                 ViBoolean* mixedMode,
                                                 ViInt32* screens);
ViStatus _VI_FUNC rsesci_SetTrackingGenerator (ViSession instrumentHandle,
                                               ViInt32 window,
                                               ViBoolean trackingGenerator);
ViStatus _VI_FUNC rsesci_GetTrackingGenerator (ViSession instrumentHandle,
                                               ViInt32 window,
                                               ViBoolean* trackingGenerator);
ViStatus _VI_FUNC rsesci_SetTrackingGeneratorSourcePower (ViSession instrumentHandle,
                                                          ViInt32 window,
                                                          ViReal64 outputLevel);
ViStatus _VI_FUNC rsesci_GetTrackingGeneratorSourcePower (ViSession instrumentHandle,
                                                          ViInt32 window,
                                                          ViReal64* outputLevel);
ViStatus _VI_FUNC rsesci_SetTrackingGeneratorPowerOffset (ViSession instrumentHandle,
                                                          ViInt32 window,
                                                          ViReal64 levelOffset);
ViStatus _VI_FUNC rsesci_GetTrackingGeneratorPowerOffset (ViSession instrumentHandle,
                                                          ViInt32 window,
                                                          ViReal64* levelOffset);
ViStatus _VI_FUNC rsesci_SetTrackingGeneratorFrequencyOffset
             (ViSession instrumentHandle, ViInt32 window, ViReal64 frequencyOffset);
ViStatus _VI_FUNC rsesci_GetTrackingGeneratorFrequencyOffset
             (ViSession instrumentHandle, ViInt32 window,
              ViReal64* frequencyOffset);
ViStatus _VI_FUNC rsesci_ConfigureTrackingGeneratorPowerSweep
             (ViSession instrumentHandle, ViInt32 window, ViInt32 powerSweep,
              ViReal64 powerStart, ViReal64 powerStop);
ViStatus _VI_FUNC rsesci_SetTrackingGeneratorPowerSweepMode
             (ViSession instrumentHandle, ViInt32 window, ViInt32 powerSweep);
ViStatus _VI_FUNC rsesci_GetTrackingGeneratorPowerSweepMode
             (ViSession instrumentHandle, ViInt32 window, ViInt32* powerSweep);
ViStatus _VI_FUNC rsesci_SetTrackingGeneratorPowerSweepStart
             (ViSession instrumentHandle, ViInt32 window, ViReal64 powerStart);
ViStatus _VI_FUNC rsesci_GetTrackingGeneratorPowerSweepStart
             (ViSession instrumentHandle, ViInt32 window, ViReal64* powerStart);
ViStatus _VI_FUNC rsesci_SetTrackingGeneratorPowerSweepStop
             (ViSession instrumentHandle, ViInt32 window, ViReal64 powerStop);
ViStatus _VI_FUNC rsesci_GetTrackingGeneratorPowerSweepStop
             (ViSession instrumentHandle, ViInt32 window, ViReal64* powerStop);
ViStatus _VI_FUNC rsesci_SetTrackingGeneratorMeasurement (ViSession instrumentHandle,
                                                          ViInt32 window,
                                                          ViInt32 measurementType);
ViStatus _VI_FUNC rsesci_GetTrackingGeneratorMeasurement (ViSession instrumentHandle,
                                                          ViInt32 window,
                                                          ViInt32* measurementType);
ViStatus _VI_FUNC rsesci_SetTrackingGeneratorNormalization
             (ViSession instrumentHandle, ViInt32 window, ViBoolean normalization);
ViStatus _VI_FUNC rsesci_GetTrackingGeneratorNormalization
             (ViSession instrumentHandle, ViInt32 window, ViBoolean* normalization);
ViStatus _VI_FUNC rsesci_TrackingGeneratorCalibration (ViSession instrumentHandle,
                                                       ViInt32 window,
                                                       ViInt32 acquisitionType);
ViStatus _VI_FUNC rsesci_TrackingGeneratorRecallSettings (ViSession instrumentHandle,
                                                          ViInt32 window);
ViStatus _VI_FUNC rsesci_TrackingGeneratorSaveAsTrdFactor
             (ViSession instrumentHandle, ViInt32 window, ViString name);
ViStatus _VI_FUNC rsesci_SetExternalAM (ViSession instrumentHandle, ViInt32 window,
                                        ViBoolean externalAM);
ViStatus _VI_FUNC rsesci_GetExternalAM (ViSession instrumentHandle, ViInt32 window,
                                        ViBoolean* externalAM);
ViStatus _VI_FUNC rsesci_SetExternalFM (ViSession instrumentHandle, ViInt32 window,
                                        ViBoolean externalFM);
ViStatus _VI_FUNC rsesci_GetExternalFM (ViSession instrumentHandle, ViInt32 window,
                                        ViBoolean* externalFM);
ViStatus _VI_FUNC rsesci_SetExternalIQModulation (ViSession instrumentHandle,
                                                  ViInt32 window,
                                                  ViBoolean IQModulation);
ViStatus _VI_FUNC rsesci_GetExternalIQModulation (ViSession instrumentHandle,
                                                  ViInt32 window,
                                                  ViBoolean* IQModulation);
ViStatus _VI_FUNC rsesci_SetExternalFMDeviation (ViSession instrumentHandle,
                                                 ViInt32 window,
                                                 ViReal64 FMDeviation);
ViStatus _VI_FUNC rsesci_GetExternalFMDeviation (ViSession instrumentHandle,
                                                 ViInt32 window,
                                                 ViReal64* FMDeviation);
ViStatus _VI_FUNC rsesci_SetExternalGenerator (ViSession instrumentHandle,
                                               ViInt32 window,
                                               ViBoolean externalGenerator);
ViStatus _VI_FUNC rsesci_GetExternalGenerator (ViSession instrumentHandle,
                                               ViInt32 window,
                                               ViBoolean* externalGenerator);
ViStatus _VI_FUNC rsesci_SetExternalGeneratorSelection (ViSession instrumentHandle,
                                                        ViInt32 generator,
                                                        ViInt32 interface,
                                                        ViString type,
                                                        ViInt32 GPIBAddress);
ViStatus _VI_FUNC rsesci_GetExternalGeneratorSelection (ViSession instrumentHandle,
                                                        ViInt32 generator,
                                                        ViInt32* interface,
                                                        ViChar _VI_FAR type[],
                                                        ViInt32* GPIBAddress);
ViStatus _VI_FUNC rsesci_SetExternalGeneratorFrequencyOffset
             (ViSession instrumentHandle, ViInt32 window, ViInt32 generator,
              ViReal64 offset);
ViStatus _VI_FUNC rsesci_GetExternalGeneratorFrequencyOffset
             (ViSession instrumentHandle, ViInt32 window, ViInt32 generator,
              ViReal64* offset);
ViStatus _VI_FUNC rsesci_SetExternalGeneratorMultiplicationFactor
             (ViSession instrumentHandle, ViInt32 window, ViInt32 generator,
              ViInt32 numerator, ViInt32 denominator);
ViStatus _VI_FUNC rsesci_GetExternalGeneratorMultiplicationFactor
             (ViSession instrumentHandle, ViInt32 window, ViInt32 generator,
              ViInt32* numerator, ViInt32* denominator);
ViStatus _VI_FUNC rsesci_SetExternalGeneratorFrequencySweep
             (ViSession instrumentHandle, ViInt32 window, ViInt32 generator,
              ViBoolean sweep);
ViStatus _VI_FUNC rsesci_GetExternalGeneratorFrequencySweep
             (ViSession instrumentHandle, ViInt32 window, ViInt32 generator,
              ViBoolean* sweep);
ViStatus _VI_FUNC rsesci_SetExternalGeneratorPower (ViSession instrumentHandle,
                                                    ViInt32 window,
                                                    ViInt32 generator,
                                                    ViReal64 power);
ViStatus _VI_FUNC rsesci_GetExternalGeneratorPower (ViSession instrumentHandle,
                                                    ViInt32 window,
                                                    ViInt32 generator,
                                                    ViReal64* power);
ViStatus _VI_FUNC rsesci_SetExternalGeneratorReferenceOscillator
             (ViSession instrumentHandle, ViInt32 window, ViInt32 generator,
              ViInt32 referenceOscillator);
ViStatus _VI_FUNC rsesci_GetExternalGeneratorReferenceOscillator
             (ViSession instrumentHandle, ViInt32 window, ViInt32 generator,
              ViInt32* referenceOscillator);
ViStatus _VI_FUNC rsesci_SendExternalGeneratorCommand (ViSession instrumentHandle,
                                                       ViInt32 GPIBAddress,
                                                       ViString command);
ViStatus _VI_FUNC rsesci_QueryExternalGeneratorCommand (ViSession instrumentHandle,
                                                        ViInt32 GPIBAddress,
                                                        ViString command,
                                                        ViInt32 arraySize,
                                                        ViChar _VI_FAR result[]);
ViStatus _VI_FUNC rsesci_SetAnalogDemodulator (ViSession instrumentHandle,
                                               ViBoolean analogDemodulator);
ViStatus _VI_FUNC rsesci_GetAnalogDemodulator (ViSession instrumentHandle,
                                               ViBoolean* analogDemodulator);
ViStatus _VI_FUNC rsesci_SetAnalogDemodulatorParameters (ViSession instrumentHandle,
                                                         ViReal64 sampleRate,
                                                         ViInt32 recordLength,
                                                         ViInt32 triggerSource,
                                                         ViInt32 triggerSlope,
                                                         ViInt32 offsetSamples,
                                                         ViInt32 number_ofMeas);
ViStatus _VI_FUNC rsesci_GetAnalogDemodulatorParameters (ViSession instrumentHandle,
                                                         ViReal64* sampleRate,
                                                         ViInt32* recordLength,
                                                         ViInt32* triggerSource,
                                                         ViInt32* triggerSlope,
                                                         ViInt32* offsetSamples,
                                                         ViInt32* number_ofMeas);
ViStatus _VI_FUNC rsesci_SetAnalogDemodulatorResultDisplay
             (ViSession instrumentHandle, ViInt32 resultDisplay, ViInt32 trace);
ViStatus _VI_FUNC rsesci_SetAnalogDemodulationMeasurementTime
             (ViSession instrumentHandle, ViReal64 measurementTime);
ViStatus _VI_FUNC rsesci_GetAnalogDemodulationMeasurementTime
             (ViSession instrumentHandle, ViReal64* measurementTime);
ViStatus _VI_FUNC rsesci_GetAnalogDemodulationSampleRate (ViSession instrumentHandle,
                                                          ViReal64* sampleRate);
ViStatus _VI_FUNC rsesci_GetAnalogDemodulationRecordLength
             (ViSession instrumentHandle, ViReal64* recordLength);
ViStatus _VI_FUNC rsesci_SetAnalogDemodulationPhaseWrap (ViSession instrumentHandle,
                                                         ViInt32 type);
ViStatus _VI_FUNC rsesci_GetAnalogDemodulationPhaseWrap (ViSession instrumentHandle,
                                                         ViInt32* type);
ViStatus _VI_FUNC rsesci_SetAnalogDemodulationZeroPhaseRefPoint
             (ViSession instrumentHandle, ViReal64 zeroPhaseRefPoint);
ViStatus _VI_FUNC rsesci_GetAnalogDemodulationZeroPhaseRefPoint
             (ViSession instrumentHandle, ViReal64* zeroPhaseRefPoint);
ViStatus _VI_FUNC rsesci_ConfigureAnalogDemodulationFilter
             (ViSession instrumentHandle, ViInt32 filterType, ViBoolean filterState,
              ViReal64 filterFrequency, ViReal64 AMFMDeemphasisValue);
ViStatus _VI_FUNC rsesci_SetAnalogDemodulationFilterState
             (ViSession instrumentHandle, ViInt32 filterType,
              ViBoolean filterState);
ViStatus _VI_FUNC rsesci_GetAnalogDemodulationFilterState
             (ViSession instrumentHandle, ViInt32 filterType,
              ViBoolean* filterState);
ViStatus _VI_FUNC rsesci_SetAnalogDemodulationFilterFrequency
             (ViSession instrumentHandle, ViInt32 filterType,
              ViReal64 filterFrequency);
ViStatus _VI_FUNC rsesci_GetAnalogDemodulationFilterFrequency
             (ViSession instrumentHandle, ViInt32 filterType,
              ViReal64* filterFrequency);
ViStatus _VI_FUNC rsesci_SetAnalogDemodulationFilterDeemphasis
             (ViSession instrumentHandle, ViReal64 AMFMDeemphasisValue);
ViStatus _VI_FUNC rsesci_GetAnalogDemodulationFilterDeemphasis
             (ViSession instrumentHandle, ViReal64* AMFMDeemphasisValue);

ViStatus _VI_FUNC rsesci_SetAnalogDemodulationCCIRUnweightedFilterState (ViSession instrumentHandle,
                                                                         ViBoolean state);

ViStatus _VI_FUNC rsesci_GetAnalogDemodulationCCIRUnweightedFilterState (ViSession instrumentHandle,
                                                                         ViBoolean *state);

ViStatus _VI_FUNC rsesci_SetAnalogDemodulationCCIRWeightedFilterState (ViSession instrumentHandle,
                                                                       ViBoolean state);

ViStatus _VI_FUNC rsesci_GetAnalogDemodulationCCIRWeightedFilterState (ViSession instrumentHandle,
                                                                       ViBoolean *state);

ViStatus _VI_FUNC rsesci_SetAnalogDemodulationAWeightedFilterState (ViSession instrumentHandle,
                                                                    ViBoolean state);

ViStatus _VI_FUNC rsesci_GetAnalogDemodulationAWeightedFilterState (ViSession instrumentHandle,
                                                                    ViBoolean *state);

ViStatus _VI_FUNC rsesci_SetAFCenterFrequency (ViSession instrumentHandle,
                                               ViReal64 centerFrequency);
ViStatus _VI_FUNC rsesci_GetAFCenterFrequency (ViSession instrumentHandle,
                                               ViReal64* centerFrequency);
ViStatus _VI_FUNC rsesci_SetAFStartFrequency (ViSession instrumentHandle,
                                              ViReal64 startFrequency);
ViStatus _VI_FUNC rsesci_GetAFStartFrequency (ViSession instrumentHandle,
                                              ViReal64* startFrequency);
ViStatus _VI_FUNC rsesci_SetAFStopFrequency (ViSession instrumentHandle,
                                             ViReal64 stopFrequency);
ViStatus _VI_FUNC rsesci_GetAFStopFrequency (ViSession instrumentHandle,
                                             ViReal64* stopFrequency);
ViStatus _VI_FUNC rsesci_AutomaticSignalSearch (ViSession instrumentHandle);
ViStatus _VI_FUNC rsesci_SetAFSpan (ViSession instrumentHandle, ViReal64 span);
ViStatus _VI_FUNC rsesci_GetAFSpan (ViSession instrumentHandle, ViReal64* span);
ViStatus _VI_FUNC rsesci_SetAFFullSpan (ViSession instrumentHandle);
ViStatus _VI_FUNC rsesci_SetRFFrequencySpan (ViSession instrumentHandle,
                                             ViReal64 span);
ViStatus _VI_FUNC rsesci_GetRFFrequencySpan (ViSession instrumentHandle,
                                             ViReal64* span);
ViStatus _VI_FUNC rsesci_SetMaxRFFrequencySpan (ViSession instrumentHandle,
                                                ViReal64 span);
ViStatus _VI_FUNC rsesci_GetMaxRFFrequencySpan (ViSession instrumentHandle,
                                                ViReal64* span);
ViStatus _VI_FUNC rsesci_SetAnalogDemodulationBandwidth (ViSession instrumentHandle,
                                                         ViReal64 demodulationBandwidth);
ViStatus _VI_FUNC rsesci_GetAnalogDemodulationBandwidth (ViSession instrumentHandle,
                                                         ViReal64* demodulationBandwidth);
ViStatus _VI_FUNC rsesci_SetAnalogDemodulationResolutionBandwidth
             (ViSession instrumentHandle, ViReal64 resolutionBandwidth);
ViStatus _VI_FUNC rsesci_GetAnalogDemodulationResolutionBandwidth
             (ViSession instrumentHandle, ViReal64* resolutionBandwidth);
ViStatus _VI_FUNC rsesci_SetAFInputCoupling (ViSession instrumentHandle,
                                             ViInt32 AFInputCoupling);
ViStatus _VI_FUNC rsesci_GetAFInputCoupling (ViSession instrumentHandle,
                                             ViInt32* AFInputCoupling);
ViStatus _VI_FUNC rsesci_SetAnalogDemodulationAngleUnits (ViSession instrumentHandle,
                                                          ViInt32 angleUnits);
ViStatus _VI_FUNC rsesci_GetAnalogDemodulationAngleUnits (ViSession instrumentHandle,
                                                          ViInt32* angleUnits);
ViStatus _VI_FUNC rsesci_SetAnalogDemodulationZoom (ViSession instrumentHandle,
                                                    ViBoolean zoom);
ViStatus _VI_FUNC rsesci_GetAnalogDemodulationZoom (ViSession instrumentHandle,
                                                    ViBoolean* zoom);
ViStatus _VI_FUNC rsesci_SetAnalogDemodulationZoomStart (ViSession instrumentHandle,
                                                         ViReal64 zoomStart);
ViStatus _VI_FUNC rsesci_GetAnalogDemodulationZoomStart (ViSession instrumentHandle,
                                                         ViReal64* zoomStart);
ViStatus _VI_FUNC rsesci_GetFMModulationMeasurement (ViSession instrumentHandle,
                                                     ViInt32 window, ViInt32 marker,
                                                     ViInt32 trace,
                                                     ViInt32 measurement,
                                                     ViReal64* result);
ViStatus _VI_FUNC rsesci_GetPMModulationMeasurement (ViSession instrumentHandle,
                                                     ViInt32 window, ViInt32 marker,
                                                     ViInt32 trace,
                                                     ViInt32 measurement,
                                                     ViReal64* result);
ViStatus _VI_FUNC rsesci_GetAMModulationMeasurement (ViSession instrumentHandle,
                                                     ViInt32 window, ViInt32 marker,
                                                     ViInt32 trace,
                                                     ViInt32 measurement,
                                                     ViReal64* result);
ViStatus _VI_FUNC rsesci_GetAnalogDemodulationAudioFrequency
             (ViSession instrumentHandle, ViInt32 window, ViInt32 marker,
              ViInt32 trace, ViReal64* result);
ViStatus _VI_FUNC rsesci_GetAnalogDemodulationFrequencyError
             (ViSession instrumentHandle, ViInt32 window, ViInt32 marker,
              ViInt32 trace, ViReal64* result);
ViStatus _VI_FUNC rsesci_GetAnalogDemodulationSINAD (ViSession instrumentHandle,
                                                     ViInt32 window, ViInt32 marker,
                                                     ViInt32 trace,
                                                     ViReal64* result);
ViStatus _VI_FUNC rsesci_GetAnalogDemodulationTHD (ViSession instrumentHandle,
                                                   ViInt32 window, ViInt32 marker,
                                                   ViInt32 trace, ViReal64* result);
ViStatus _VI_FUNC rsesci_GetAnalogDemodulationCarrierPower
             (ViSession instrumentHandle, ViInt32 window, ViInt32 marker,
              ViInt32 trace, ViReal64* result);
ViStatus _VI_FUNC rsesci_SetAFSpectrumResultTypes (ViSession instrumentHandle,
                                                   ViInt32 demodulationType,
                                                   ViInt32 resultType1,
                                                   ViInt32 resultType2,
                                                   ViInt32 resultType3);
ViStatus _VI_FUNC rsesci_GetAFSpectrumResultValues (ViSession instrumentHandle,
                                                    ViInt32 demodulationType,
                                                    ViInt32 resultType,
                                                    ViInt32 arraySize,
                                                    ViInt32* number_ofResults,
                                                    ViReal64 _VI_FAR results[]);
ViStatus _VI_FUNC rsesci_SetRFSpectrumResultTypes (ViSession instrumentHandle,
                                                   ViInt32 resultType1,
                                                   ViInt32 resultType2,
                                                   ViInt32 resultType3);
ViStatus _VI_FUNC rsesci_GetRFSpectrumResultValues (ViSession instrumentHandle,
                                                    ViInt32 resultType,
                                                    ViInt32 arraySize,
                                                    ViInt32* number_ofResults,
                                                    ViReal64 _VI_FAR results[]);
ViStatus _VI_FUNC rsesci_SetTimeDomainResultTypes (ViSession instrumentHandle,
                                                   ViInt32 demodulationType,
                                                   ViInt32 resultType1,
                                                   ViInt32 resultType2,
                                                   ViInt32 resultType3);
ViStatus _VI_FUNC rsesci_GetTimeDomainResultValues (ViSession instrumentHandle,
                                                    ViInt32 demodulationType,
                                                    ViInt32 resultType,
                                                    ViInt32 arraySize,
                                                    ViInt32* number_ofResults,
                                                    ViReal64 _VI_FAR results[]);
ViStatus _VI_FUNC rsesci_GetFMOffsetValue (ViSession instrumentHandle,
                                           ViInt32 measurement, ViReal64* result);
ViStatus _VI_FUNC rsesci_SetDataAveraging (ViSession instrumentHandle,
                                           ViInt32 window, ViInt32 trace,
                                           ViBoolean dataAveraging);
ViStatus _VI_FUNC rsesci_GetDataAveraging (ViSession instrumentHandle,
                                           ViInt32 window, ViInt32 trace,
                                           ViBoolean* dataAveraging);
ViStatus _VI_FUNC rsesci_SetAverageCount (ViSession instrumentHandle,
                                          ViInt32 window, ViInt32 averageCount);
ViStatus _VI_FUNC rsesci_GetAverageCount (ViSession instrumentHandle,
                                          ViInt32 window, ViInt32* averageCount);
ViStatus _VI_FUNC rsesci_SetAverageType (ViSession instrumentHandle, ViInt32 window,
                                         ViInt32 averageType);
ViStatus _VI_FUNC rsesci_GetAverageType (ViSession instrumentHandle, ViInt32 window,
                                         ViInt32* averageType);
ViStatus _VI_FUNC rsesci_SetLimitLineName (ViSession instrumentHandle,
                                           ViInt32 limit, ViString name);
ViStatus _VI_FUNC rsesci_GetLimitLineName (ViSession instrumentHandle,
                                           ViInt32 limit, ViChar _VI_FAR name[]);
ViStatus _VI_FUNC rsesci_SetLimitLineVisible (ViSession instrumentHandle,
                                              ViInt32 window, ViInt32 limit,
                                              ViInt32 limitType, ViBoolean state);
ViStatus _VI_FUNC rsesci_GetLimitLineVisible (ViSession instrumentHandle,
                                              ViInt32 window, ViInt32 limit,
                                              ViInt32 limitType, ViBoolean* state);
ViStatus _VI_FUNC rsesci_SetLimitLineTrace (ViSession instrumentHandle,
                                            ViInt32 window, ViInt32 limit,
                                            ViInt32 trace);
ViStatus _VI_FUNC rsesci_GetLimitLineTrace (ViSession instrumentHandle,
                                            ViInt32 window, ViInt32 limit,
                                            ViInt32* trace);
ViStatus _VI_FUNC rsesci_CopyLimitLine (ViSession instrumentHandle,
                                        ViInt32 sourceLimit,
                                        ViInt32 destinationLimit);
ViStatus _VI_FUNC rsesci_DeleteLimitLine (ViSession instrumentHandle,
                                          ViInt32 limit);
ViStatus _VI_FUNC rsesci_SetLimitLineXOffset (ViSession instrumentHandle,
                                              ViInt32 window, ViInt32 limit,
                                              ViReal64 offset);
ViStatus _VI_FUNC rsesci_GetLimitLineXOffset (ViSession instrumentHandle,
                                              ViInt32 window, ViInt32 limit,
                                              ViReal64* offset);
ViStatus _VI_FUNC rsesci_SetLimitLineYOffset (ViSession instrumentHandle,
                                              ViInt32 limit, ViInt32 limitType,
                                              ViReal64 offset);
ViStatus _VI_FUNC rsesci_GetLimitLineYOffset (ViSession instrumentHandle,
                                              ViInt32 limit, ViInt32 limitType,
                                              ViReal64* offset);
ViStatus _VI_FUNC rsesci_GetActiveLimitLines (ViSession instrumentHandle,
                                              ViInt32 arraySize,
                                              ViChar _VI_FAR activeLimitLines[]);
ViStatus _VI_FUNC rsesci_SetLimitLineCheck (ViSession instrumentHandle,
                                            ViInt32 window, ViInt32 limit,
                                            ViBoolean limitCheck);
ViStatus _VI_FUNC rsesci_GetLimitLineCheck (ViSession instrumentHandle,
                                            ViInt32 window, ViInt32 limit,
                                            ViBoolean* limitCheck);
ViStatus _VI_FUNC rsesci_GetLimitLineCheckResult (ViSession instrumentHandle,
                                                  ViInt32 window, ViInt32 limit,
                                                  ViInt32* result);
ViStatus _VI_FUNC rsesci_ClearLimitLineCheckResult (ViSession instrumentHandle,
                                                    ViInt32 window);
ViStatus _VI_FUNC rsesci_SetLimitLineDomain (ViSession instrumentHandle,
                                             ViInt32 window, ViInt32 limit,
                                             ViInt32 domain);
ViStatus _VI_FUNC rsesci_GetLimitLineDomain (ViSession instrumentHandle,
                                             ViInt32 window, ViInt32 limit,
                                             ViInt32* domain);
ViStatus _VI_FUNC rsesci_SetLimitLineInterpolation (ViSession instrumentHandle,
                                                    ViInt32 window, ViInt32 limit,
                                                    ViInt32 interpolationAxis,
                                                    ViInt32 interpolation);
ViStatus _VI_FUNC rsesci_GetLimitLineInterpolation (ViSession instrumentHandle,
                                                    ViInt32 window, ViInt32 limit,
                                                    ViInt32 interpolationAxis,
                                                    ViInt32* interpolation);
ViStatus _VI_FUNC rsesci_SetLimitLineScaling (ViSession instrumentHandle,
                                              ViInt32 limit,
                                              ViInt32 interpolationAxis,
                                              ViInt32 limitLineScaling);
ViStatus _VI_FUNC rsesci_GetLimitLineScaling (ViSession instrumentHandle,
                                              ViInt32 limit,
                                              ViInt32 interpolationAxis,
                                              ViInt32* limitLineScaling);
ViStatus _VI_FUNC rsesci_SetLimitLineUnit (ViSession instrumentHandle,
                                           ViInt32 limit, ViInt32 levelAxisUnit);
ViStatus _VI_FUNC rsesci_GetLimitLineUnit (ViSession instrumentHandle,
                                           ViInt32 limit, ViInt32* levelAxisUnit);
ViStatus _VI_FUNC rsesci_SetLimitLineMargin (ViSession instrumentHandle,
                                             ViInt32 limit, ViInt32 limitLineType,
                                             ViReal64 margin);
ViStatus _VI_FUNC rsesci_GetLimitLineMargin (ViSession instrumentHandle,
                                             ViInt32 limit, ViInt32 limitLineType,
                                             ViReal64* margin);
ViStatus _VI_FUNC rsesci_SetLimitLineThreshold (ViSession instrumentHandle,
                                                ViInt32 limit,
                                                ViInt32 limitLineType,
                                                ViReal64 threshold);
ViStatus _VI_FUNC rsesci_GetLimitLineThreshold (ViSession instrumentHandle,
                                                ViInt32 limit,
                                                ViInt32 limitLineType,
                                                ViReal64* threshold);
ViStatus _VI_FUNC rsesci_SetLimitLineComment (ViSession instrumentHandle,
                                              ViInt32 limit, ViString comment);
ViStatus _VI_FUNC rsesci_GetLimitLineComment (ViSession instrumentHandle,
                                              ViInt32 limit,
                                              ViChar _VI_FAR comment[]);
ViStatus _VI_FUNC rsesci_SetLimitLineValues (ViSession instrumentHandle,
                                             ViInt32 limit, ViInt32 axis,
                                             ViInt32 arraySize,
                                             ViReal64 _VI_FAR data[]);
ViStatus _VI_FUNC rsesci_GetLimitLineValues (ViSession instrumentHandle,
                                             ViInt32 limit, ViInt32 axis,
                                             ViInt32 arraySize,
                                             ViReal64 _VI_FAR data[]);
ViStatus _VI_FUNC rsesci_LimitLineShiftX (ViSession instrumentHandle, ViInt32 limit,
                                          ViReal64 shift);
ViStatus _VI_FUNC rsesci_LimitLineShiftY (ViSession instrumentHandle, ViInt32 limit,
                                          ViInt32 axisType, ViReal64 shift);
ViStatus _VI_FUNC rsesci_GetLimitLineCatalog (ViSession instrumentHandle,
                                              ViInt32 window, ViInt32 limit,
                                              ViInt32 bufferSize,
                                              ViChar _VI_FAR limitLineList[]);
ViStatus _VI_FUNC rsesci_SetDisplayLine (ViSession instrumentHandle, ViInt32 window,
                                         ViInt32 line, ViBoolean state);
ViStatus _VI_FUNC rsesci_GetDisplayLine (ViSession instrumentHandle, ViInt32 window,
                                         ViInt32 line, ViBoolean* state);
ViStatus _VI_FUNC rsesci_SetDisplayLinePosition (ViSession instrumentHandle,
                                                 ViInt32 window, ViInt32 line,
                                                 ViReal64 position);
ViStatus _VI_FUNC rsesci_GetDisplayLinePosition (ViSession instrumentHandle,
                                                 ViInt32 window, ViInt32 line,
                                                 ViReal64* position);
ViStatus _VI_FUNC rsesci_SetFrequencyLine (ViSession instrumentHandle,
                                           ViInt32 window, ViInt32 line,
                                           ViBoolean state);
ViStatus _VI_FUNC rsesci_GetFrequencyLine (ViSession instrumentHandle,
                                           ViInt32 window, ViInt32 line,
                                           ViBoolean* state);
ViStatus _VI_FUNC rsesci_SetFrequencyLinePosition (ViSession instrumentHandle,
                                                   ViInt32 window, ViInt32 line,
                                                   ViReal64 position);
ViStatus _VI_FUNC rsesci_GetFrequencyLinePosition (ViSession instrumentHandle,
                                                   ViInt32 window, ViInt32 line,
                                                   ViReal64* position);
ViStatus _VI_FUNC rsesci_SetTimeLine (ViSession instrumentHandle, ViInt32 window,
                                      ViInt32 line, ViBoolean state);
ViStatus _VI_FUNC rsesci_GetTimeLine (ViSession instrumentHandle, ViInt32 window,
                                      ViInt32 line, ViBoolean* state);
ViStatus _VI_FUNC rsesci_SetTimeLinePosition (ViSession instrumentHandle,
                                              ViInt32 window, ViInt32 line,
                                              ViReal64 position);
ViStatus _VI_FUNC rsesci_GetTimeLinePosition (ViSession instrumentHandle,
                                              ViInt32 window, ViInt32 line,
                                              ViReal64* position);
ViStatus _VI_FUNC rsesci_SetActiveWindow (ViSession instrumentHandle,
                                          ViInt32 window);
ViStatus _VI_FUNC rsesci_GetActiveWindow (ViSession instrumentHandle,
                                          ViInt32* window);
ViStatus _VI_FUNC rsesci_SetScreenMode (ViSession instrumentHandle, ViInt32 mode);
ViStatus _VI_FUNC rsesci_GetScreenMode (ViSession instrumentHandle, ViInt32* mode);
ViStatus _VI_FUNC rsesci_SetDisplaySize (ViSession instrumentHandle,
                                         ViInt32 displaySize);
ViStatus _VI_FUNC rsesci_GetDisplaySize (ViSession instrumentHandle,
                                         ViInt32* displaySize);
ViStatus _VI_FUNC rsesci_SetDisplayUpdate (ViSession instrumentHandle,
                                           ViBoolean displayUpdate);
ViStatus _VI_FUNC rsesci_GetDisplayUpdate (ViSession instrumentHandle,
                                           ViBoolean* displayUpdate);
ViStatus _VI_FUNC rsesci_SetDisplayBargraphMaxhold (ViSession instrumentHandle,
                                                    ViBoolean bargraphMaxhold);
ViStatus _VI_FUNC rsesci_GetDisplayBargraphMaxhold (ViSession instrumentHandle,
                                                    ViBoolean* bargraphMaxhold);
ViStatus _VI_FUNC rsesci_GetDisplayBargraphLevel (ViSession instrumentHandle,
                                                  ViReal64* minimumBargraphLevel,
                                                  ViReal64* maximumBargraphLevel);
ViStatus _VI_FUNC rsesci_ResetDisplayBargraphMaxhold (ViSession instrumentHandle);
ViStatus _VI_FUNC rsesci_SetParameterCoupling (ViSession instrumentHandle,
                                               ViInt32 coupledParameters,
                                               ViBoolean coupling);
ViStatus _VI_FUNC rsesci_GetParameterCoupling (ViSession instrumentHandle,
                                               ViInt32 coupledParameters,
                                               ViBoolean* coupling);
ViStatus _VI_FUNC rsesci_SetInstrumentCoupling (ViSession instrumentHandle,
                                                ViInt32 coupling);
ViStatus _VI_FUNC rsesci_SetXAxisDisplaySpacing (ViSession instrumentHandle,
                                                 ViInt32 window,
                                                 ViInt32 displaySpacing);
ViStatus _VI_FUNC rsesci_GetXAxisDisplaySpacing (ViSession instrumentHandle,
                                                 ViInt32 window,
                                                 ViInt32* displaySpacing);
ViStatus _VI_FUNC rsesci_SetXAxisDisplayZoom (ViSession instrumentHandle,
                                              ViInt32 window, ViBoolean zoomState);
ViStatus _VI_FUNC rsesci_SetScreenTitle (ViSession instrumentHandle,
                                         ViBoolean screenTitle,
                                         ViString commentString);
ViStatus _VI_FUNC rsesci_SetDisplayElements (ViSession instrumentHandle,
                                             ViBoolean annotation, ViBoolean logo,
                                             ViBoolean timeDate);
ViStatus _VI_FUNC rsesci_SetDisplayUserDefinedColors (ViSession instrumentHandle,
                                                      ViInt32 colorMap,
                                                      ViInt32 predefinedColors,
                                                      ViReal64 tint,
                                                      ViReal64 saturation,
                                                      ViReal64 brightness);
ViStatus _VI_FUNC rsesci_SetDisplayDefaultColors (ViSession instrumentHandle,
                                                  ViInt32 defaultColors);
ViStatus _VI_FUNC rsesci_SetDisplayPowerSaving (ViSession instrumentHandle,
                                                ViBoolean powerSaving,
                                                ViInt32 holdoffTime);
ViStatus _VI_FUNC rsesci_SetExternalReferenceOscillator (ViSession instrumentHandle,
                                                         ViInt32 referenceOscillator);
ViStatus _VI_FUNC rsesci_GetExternalReferenceOscillator (ViSession instrumentHandle,
                                                         ViInt32* referenceOscillator);
ViStatus _VI_FUNC rsesci_SetExternalReferenceOscillatorFrequency
             (ViSession instrumentHandle, ViReal64 externalFrequency);
ViStatus _VI_FUNC rsesci_GetExternalReferenceOscillatorFrequency
             (ViSession instrumentHandle, ViReal64* externalFrequency);
ViStatus _VI_FUNC rsesci_SetExternalNoiseSource (ViSession instrumentHandle,
                                                 ViBoolean noiseSource);
ViStatus _VI_FUNC rsesci_GetExternalNoiseSource (ViSession instrumentHandle,
                                                 ViBoolean* noiseSource);
ViStatus _VI_FUNC rsesci_SetPreselector (ViSession instrumentHandle,
                                         ViBoolean preselector);
ViStatus _VI_FUNC rsesci_GetPreselector (ViSession instrumentHandle,
                                         ViBoolean* preselector);

ViStatus _VI_FUNC rsesci_SetSwitchoverFrequencyHighpass (ViSession instrumentHandle,
                                                         ViInt32 band);

ViStatus _VI_FUNC rsesci_GetSwitchoverFrequencyHighpass (ViSession instrumentHandle,
                                                         ViInt32 *band);

ViStatus _VI_FUNC rsesci_SetTransducerFactor (ViSession instrumentHandle,
                                              ViInt32 window,
                                              ViBoolean transducerFactor);
ViStatus _VI_FUNC rsesci_GetTransducerFactor (ViSession instrumentHandle,
                                              ViInt32 window,
                                              ViBoolean* transducerFactor);
ViStatus _VI_FUNC rsesci_SetTransducerFactorName (ViSession instrumentHandle,
                                                  ViInt32 window, ViString name);
ViStatus _VI_FUNC rsesci_GetTransducerFactorName (ViSession instrumentHandle,
                                                  ViInt32 window,
                                                  ViChar _VI_FAR name[]);
ViStatus _VI_FUNC rsesci_GetTransducerFactorCatalog (ViSession instrumentHandle,
                                                     ViInt32 window,
                                                     ViInt32* number_ofTransducerFactors,
                                                     ViInt32 bufferSize,
                                                     ViChar _VI_FAR transducerFactorsList[]);
ViStatus _VI_FUNC rsesci_GetActiveTransducerFactor (ViSession instrumentHandle,
                                                    ViInt32 window,
                                                    ViInt32 bufferSize,
                                                    ViChar _VI_FAR activeTransducerFactor[]);
ViStatus _VI_FUNC rsesci_DeleteTransducerFactor (ViSession instrumentHandle,
                                                 ViInt32 window, ViString name);
ViStatus _VI_FUNC rsesci_SetTransducerFactorView (ViSession instrumentHandle,
                                                  ViInt32 window,
                                                  ViBoolean transducerFactorView);
ViStatus _VI_FUNC rsesci_GetTransducerFactorView (ViSession instrumentHandle,
                                                  ViInt32 window,
                                                  ViBoolean* transducerFactorView);
ViStatus _VI_FUNC rsesci_SetTransducerFactorAutoAdjust (ViSession instrumentHandle,
                                                        ViInt32 window,
                                                        ViBoolean autoAdjust);
ViStatus _VI_FUNC rsesci_GetTransducerFactorAutoAdjust (ViSession instrumentHandle,
                                                        ViInt32 window,
                                                        ViBoolean* autoAdjust);
ViStatus _VI_FUNC rsesci_SetTransducerSet (ViSession instrumentHandle,
                                           ViInt32 window, ViBoolean transducerSet);
ViStatus _VI_FUNC rsesci_GetTransducerSet (ViSession instrumentHandle,
                                           ViInt32 window,
                                           ViBoolean* transducerSet);
ViStatus _VI_FUNC rsesci_SetTransducerSetName (ViSession instrumentHandle,
                                               ViInt32 window, ViString name);
ViStatus _VI_FUNC rsesci_GetTransducerSetName (ViSession instrumentHandle,
                                               ViInt32 window,
                                               ViChar _VI_FAR name[]);
ViStatus _VI_FUNC rsesci_GetTransducerSetCatalog (ViSession instrumentHandle,
                                                  ViInt32 window,
                                                  ViInt32* number_ofTransducerSets,
                                                  ViInt32 bufferSize,
                                                  ViChar _VI_FAR transducerSetsList[]);
ViStatus _VI_FUNC rsesci_DeleteTransducerSet (ViSession instrumentHandle,
                                              ViInt32 window, ViString name);
ViStatus _VI_FUNC rsesci_SetTransducerFactorUnit (ViSession instrumentHandle,
                                                  ViInt32 window,
                                                  ViInt32 transducerFactorUnit);
ViStatus _VI_FUNC rsesci_GetTransducerFactorUnit (ViSession instrumentHandle,
                                                  ViInt32 window,
                                                  ViInt32* transducerFactorUnit);
ViStatus _VI_FUNC rsesci_SetTransducerFactorInterpolation
             (ViSession instrumentHandle, ViInt32 window,
              ViInt32 transducerFactorInterpolation);
ViStatus _VI_FUNC rsesci_GetTransducerFactorInterpolation
             (ViSession instrumentHandle, ViInt32 window,
              ViInt32* transducerFactorInterpolation);
ViStatus _VI_FUNC rsesci_SetTransducerFactorComment (ViSession instrumentHandle,
                                                     ViInt32 window,
                                                     ViString comment);
ViStatus _VI_FUNC rsesci_GetTransducerFactorComment (ViSession instrumentHandle,
                                                     ViInt32 window,
                                                     ViChar _VI_FAR comment[]);
ViStatus _VI_FUNC rsesci_SetTransducerFactorValues (ViSession instrumentHandle,
                                                    ViInt32 window,
                                                    ViInt32 arraySize,
                                                    ViReal64 _VI_FAR frequencyValues[],
                                                    ViReal64 _VI_FAR levelValues[]);
ViStatus _VI_FUNC rsesci_GetTransducerFactorValues (ViSession instrumentHandle,
                                                    ViInt32 window,
                                                    ViInt32* number_ofResults,
                                                    ViReal64 _VI_FAR frequencyValues[],
                                                    ViReal64 _VI_FAR levelValues[]);
ViStatus _VI_FUNC rsesci_SetTransducerSetUnit (ViSession instrumentHandle,
                                               ViInt32 window,
                                               ViInt32 transducerSetUnit);
ViStatus _VI_FUNC rsesci_GetTransducerSetUnit (ViSession instrumentHandle,
                                               ViInt32 window,
                                               ViInt32* transducerSetUnit);
ViStatus _VI_FUNC rsesci_SetTransducerSetBreak (ViSession instrumentHandle,
                                                ViInt32 window,
                                                ViBoolean transducerSetBreak);
ViStatus _VI_FUNC rsesci_GetTransducerSetBreak (ViSession instrumentHandle,
                                                ViInt32 window,
                                                ViBoolean* transducerSetBreak);
ViStatus _VI_FUNC rsesci_SetTransducerSetComment (ViSession instrumentHandle,
                                                  ViInt32 window, ViString comment);
ViStatus _VI_FUNC rsesci_GetTransducerSetComment (ViSession instrumentHandle,
                                                  ViInt32 window,
                                                  ViChar _VI_FAR comment[]);
ViStatus _VI_FUNC rsesci_SetTransducerSetValues (ViSession instrumentHandle,
                                                 ViInt32 window, ViInt32 range,
                                                 ViReal64 startFrequency,
                                                 ViReal64 stopFrequency,
                                                 ViString factors);
ViStatus _VI_FUNC rsesci_GetTransducerSetValues (ViSession instrumentHandle,
                                                 ViInt32 window, ViInt32 range,
                                                 ViReal64* startFrequency,
                                                 ViReal64* stopFrequency,
                                                 ViChar _VI_FAR factors[]);
ViStatus _VI_FUNC rsesci_SetGPIBAddress (ViSession instrumentHandle,
                                         ViInt32 GPIBAddress);
ViStatus _VI_FUNC rsesci_GetGPIBAddress (ViSession instrumentHandle,
                                         ViInt32* GPIBAddress);
ViStatus _VI_FUNC rsesci_SetSerialInterfaceConfiguration (ViSession instrumentHandle,
                                                          ViInt32 baudRate,
                                                          ViInt32 dataBits,
                                                          ViInt32 stopBits,
                                                          ViBoolean hardwareHandshake,
                                                          ViBoolean softwareHandshake,
                                                          ViInt32 parity);
ViStatus _VI_FUNC rsesci_GetSerialInterfaceConfiguration (ViSession instrumentHandle,
                                                          ViInt32* baudRate,
                                                          ViInt32* dataBits,
                                                          ViInt32* stopBits,
                                                          ViBoolean* hardwareHandshake,
                                                          ViBoolean* softwareHandshake,
                                                          ViInt32* parity);
ViStatus _VI_FUNC rsesci_SetSystemTime (ViSession instrumentHandle, ViInt32 hour,
                                        ViInt32 minute, ViInt32 second);
ViStatus _VI_FUNC rsesci_GetSystemTime (ViSession instrumentHandle, ViInt32* hour,
                                        ViInt32* minute, ViInt32* second);
ViStatus _VI_FUNC rsesci_SetSystemDate (ViSession instrumentHandle, ViInt32 day,
                                        ViInt32 month, ViInt32 year);
ViStatus _VI_FUNC rsesci_GetSystemDate (ViSession instrumentHandle, ViInt32* day,
                                        ViInt32* month, ViInt32* year);
ViStatus _VI_FUNC rsesci_SetSpeakerVolume (ViSession instrumentHandle,
                                           ViReal64 speakerVolume);
ViStatus _VI_FUNC rsesci_GetSpeakerVolume (ViSession instrumentHandle,
                                           ViReal64* speakerVolume);
ViStatus _VI_FUNC rsesci_SetSoftFrontpanel (ViSession instrumentHandle,
                                            ViBoolean softFrontpanel);
ViStatus _VI_FUNC rsesci_GetSoftFrontpanel (ViSession instrumentHandle,
                                            ViBoolean* softFrontpanel);
ViStatus _VI_FUNC rsesci_SetUserPort (ViSession instrumentHandle, ViInt32 userPort);
ViStatus _VI_FUNC rsesci_GetUserPort (ViSession instrumentHandle,
                                      ViInt32* userPort);
ViStatus _VI_FUNC rsesci_ReadUserPortValue (ViSession instrumentHandle,
                                            ViBoolean _VI_FAR userPortValue[]);
ViStatus _VI_FUNC rsesci_WriteUserPortValue (ViSession instrumentHandle,
                                             ViBoolean _VI_FAR userPortValue[]);
ViStatus _VI_FUNC rsesci_SetServiceSource (ViSession instrumentHandle,
                                           ViInt32 window, ViInt32 serviceSource,
                                           ViReal64 calibrationSourceLevel);
ViStatus _VI_FUNC rsesci_GetServiceSource (ViSession instrumentHandle,
                                           ViInt32 window, ViInt32* serviceSource,
                                           ViReal64* calibrationSourceLevel);
ViStatus _VI_FUNC rsesci_SetServicePulseGenerator (ViSession instrumentHandle,
                                                   ViInt32 window,
                                                   ViBoolean pulseGenerator,
                                                   ViReal64 pulseRate);
ViStatus _VI_FUNC rsesci_GetServicePulseGenerator (ViSession instrumentHandle,
                                                   ViInt32 window,
                                                   ViBoolean* pulseGenerator,
                                                   ViReal64* pulseRate);
ViStatus _VI_FUNC rsesci_ServiceConfigureRectangleCalibrationSignal
             (ViSession instrumentHandle, ViInt32 window, ViBoolean state,
              ViReal64 frequency);
ViStatus _VI_FUNC rsesci_SetIFShift (ViSession instrumentHandle, ViInt32 IFShift);
ViStatus _VI_FUNC rsesci_GetIFShift (ViSession instrumentHandle, ViInt32* IFShift);
ViStatus _VI_FUNC rsesci_SetCalibrationSignalDestination (ViSession instrumentHandle,
                                                          ViInt32 signalDestination);
ViStatus _VI_FUNC rsesci_GetCalibrationSignalDestination (ViSession instrumentHandle,
                                                          ViInt32* signalDestination);
ViStatus _VI_FUNC rsesci_SetCalibrationSignalVoltage (ViSession instrumentHandle,
                                                      ViInt32 signalVoltage);
ViStatus _VI_FUNC rsesci_GetCalibrationSignalVoltage (ViSession instrumentHandle,
                                                      ViInt32* signalVoltage);
ViStatus _VI_FUNC rsesci_SetCalibrationSignalPulseFrequency
             (ViSession instrumentHandle, ViInt32 pulseFrequency);
ViStatus _VI_FUNC rsesci_GetCalibrationSignalPulseFrequency
             (ViSession instrumentHandle, ViInt32* pulseFrequency);
ViStatus _VI_FUNC rsesci_SetCalibrationSignalBasebandSource
             (ViSession instrumentHandle, ViInt32 basebandSource);
ViStatus _VI_FUNC rsesci_GetCalibrationSignalBasebandSource
             (ViSession instrumentHandle, ViInt32* basebandSource);
ViStatus _VI_FUNC rsesci_SetServiceRectangleState (ViSession instrumentHandle,
                                                   ViInt32 window, ViBoolean state);
ViStatus _VI_FUNC rsesci_GetServiceRectangleState (ViSession instrumentHandle,
                                                   ViInt32 window,
                                                   ViBoolean* state);
ViStatus _VI_FUNC rsesci_SetServiceRectangleRate (ViSession instrumentHandle,
                                                  ViInt32 window,
                                                  ViReal64 frequency);
ViStatus _VI_FUNC rsesci_GetServiceRectangleRate (ViSession instrumentHandle,
                                                  ViInt32 window,
                                                  ViReal64* frequency);
ViStatus _VI_FUNC rsesci_FirmwareUpdate (ViSession instrumentHandle, ViString path);
ViStatus _VI_FUNC rsesci_CompatibilityMode (ViSession instrumentHandle,
                                            ViInt32 compatibilityMode);
ViStatus _VI_FUNC rsesci_DataSetSave (ViSession instrumentHandle, ViString fileName,
                                      ViString comment);
ViStatus _VI_FUNC rsesci_DataSetRecall (ViSession instrumentHandle,
                                        ViString fileName);
ViStatus _VI_FUNC rsesci_DataSetRecallAuto (ViSession instrumentHandle,
                                            ViString fileName);
ViStatus _VI_FUNC rsesci_DataSetItems (ViSession instrumentHandle,
                                       ViInt32 dataSetItems,
                                       ViBoolean selectedItem);
ViStatus _VI_FUNC rsesci_DataSetCatalog (ViSession instrumentHandle,
                                         ViString directory,
                                         ViChar _VI_FAR catalog[],
                                         ViInt32 bufferSize);
ViStatus _VI_FUNC rsesci_DataSetCatalogLong (ViSession instrumentHandle,
                                             ViString directory,
                                             ViChar _VI_FAR catalog[],
                                             ViInt32 bufferSize);
ViStatus _VI_FUNC rsesci_DataSetClear (ViSession instrumentHandle, ViInt32 clear,
                                       ViString path);
ViStatus _VI_FUNC rsesci_FileManager (ViSession instrumentHandle,
                                      ViInt32 operation_to_bePerformed,
                                      ViString source, ViString destination);
ViStatus _VI_FUNC rsesci_StoreTraceData (ViSession instrumentHandle, ViInt32 trace,
                                         ViString fileName);
ViStatus _VI_FUNC rsesci_StoreFinalMeasurementData (ViSession instrumentHandle,
                                                    ViString fileName);
ViStatus _VI_FUNC rsesci_StorePeakList (ViSession instrumentHandle,
                                        ViString fileName);
ViStatus _VI_FUNC rsesci_StoreMarkers (ViSession instrumentHandle, ViInt32 window,
                                       ViString fileName);
ViStatus _VI_FUNC rsesci_readToFile (ViSession instrumentHandle, ViString source,
                                     ViString destination);
ViStatus _VI_FUNC rsesci_writeFromFile (ViSession instrumentHandle, ViString source,
                                        ViString destination);
ViStatus _VI_FUNC rsesci_SetDecimalPointNotation (ViSession instrumentHandle,
                                                  ViInt32 decimalSeparator);
ViStatus _VI_FUNC rsesci_GetDecimalPointNotation (ViSession instrumentHandle,
                                                  ViInt32* decimalSeparator);
ViStatus _VI_FUNC rsesci_SelectPrinter (ViSession instrumentHandle,
                                        ViInt32 deviceNumber, ViString printerName);
ViStatus _VI_FUNC rsesci_QueryPrinterList (ViSession instrumentHandle,
                                           ViChar _VI_FAR printerList[]);
ViStatus _VI_FUNC rsesci_AbortHardcopy (ViSession instrumentHandle);
ViStatus _VI_FUNC rsesci_InitiateHardcopy (ViSession instrumentHandle,
                                           ViInt32 deviceNumber);
ViStatus _VI_FUNC rsesci_HardcopyDeviceSetup (ViSession instrumentHandle,
                                              ViInt32 deviceNumber,
                                              ViInt32 destination,
                                              ViInt32 dataFormat,
                                              ViInt32 pageOrientation,
                                              ViString fileName);
ViStatus _VI_FUNC rsesci_HardcopyComment (ViSession instrumentHandle,
                                          ViInt32 window, ViString comment);
ViStatus _VI_FUNC rsesci_HardcopyItems (ViSession instrumentHandle, ViInt32 window,
                                        ViInt32 hardcopyItems);
ViStatus _VI_FUNC rsesci_HardcopyColor (ViSession instrumentHandle,
                                        ViBoolean color);
ViStatus _VI_FUNC rsesci_HardcopyUserDefinedColors (ViSession instrumentHandle,
                                                    ViInt32 colorMap,
                                                    ViInt32 predefinedColors,
                                                    ViReal64 tint,
                                                    ViReal64 saturation,
                                                    ViReal64 brightness);
ViStatus _VI_FUNC rsesci_HardcopyDefaultColors (ViSession instrumentHandle,
                                                ViInt32 defaultColors);
ViStatus _VI_FUNC rsesci_InitiateHardcopyToFile (ViSession instrumentHandle,
                                                 ViInt32 deviceNumber,
                                                 ViString destination,
                                                 ViInt32 dataFormat,
                                                 ViInt32 pageOrientation);
ViStatus _VI_FUNC rsesci_SetHardcopyOutput (ViSession instrumentHandle,
                                            ViInt32 output);
ViStatus _VI_FUNC rsesci_GetHardcopyOutput (ViSession instrumentHandle,
                                            ViInt32* output);
ViStatus _VI_FUNC rsesci_CreateNewTestReport (ViSession instrumentHandle);
ViStatus _VI_FUNC rsesci_AppendTestReport (ViSession instrumentHandle);
ViStatus _VI_FUNC rsesci_SetTestReportDefaultSettings (ViSession instrumentHandle);
ViStatus _VI_FUNC rsesci_ConfigureTestReportPageSettings (ViSession instrumentHandle,
                                                          ViInt32 itemSelector,
                                                          ViBoolean state);
ViStatus _VI_FUNC rsesci_QueryTestReportPageSettings (ViSession instrumentHandle,
                                                      ViInt32 itemSelector,
                                                      ViBoolean* state);
ViStatus _VI_FUNC rsesci_SetTestReportHeaderLineState (ViSession instrumentHandle,
                                                       ViInt32 lineNumber,
                                                       ViInt32 state);
ViStatus _VI_FUNC rsesci_GetTestReportHeaderLineState (ViSession instrumentHandle,
                                                       ViInt32 lineNumber,
                                                       ViInt32* state);
ViStatus _VI_FUNC rsesci_SetTestReportHeaderLogoState (ViSession instrumentHandle,
                                                       ViInt32 state);
ViStatus _VI_FUNC rsesci_GetTestReportHeaderLogoState (ViSession instrumentHandle,
                                                       ViInt32* state);
ViStatus _VI_FUNC rsesci_SetTestReportHeaderLineTitle (ViSession instrumentHandle,
                                                       ViInt32 lineNumber,
                                                       ViString lineTitle);
ViStatus _VI_FUNC rsesci_GetTestReportHeaderLineTitle (ViSession instrumentHandle,
                                                       ViInt32 lineNumber,
                                                       ViInt32 arraySize,
                                                       ViChar _VI_FAR lineTitle[]);
ViStatus _VI_FUNC rsesci_SetTestReportHeaderLineText (ViSession instrumentHandle,
                                                      ViInt32 lineNumber,
                                                      ViString lineText);
ViStatus _VI_FUNC rsesci_GetTestReportHeaderLineText (ViSession instrumentHandle,
                                                      ViInt32 lineNumber,
                                                      ViInt32 arraySize,
                                                      ViChar _VI_FAR lineText[]);
ViStatus _VI_FUNC rsesci_TestReportOperations (ViSession instrumentHandle,
                                               ViInt32 operation,
                                               ViString testReportName);
ViStatus _VI_FUNC rsesci_LoadLogo (ViSession instrumentHandle, ViString directory,
                                   ViString fileName);
ViStatus _VI_FUNC rsesci_GetTestReportCatalog (ViSession instrumentHandle,
                                               ViInt32* number_ofTestReports,
                                               ViInt32 bufferSize,
                                               ViChar _VI_FAR testReportList[]);
ViStatus _VI_FUNC rsesci_errorCheckState (ViSession instrumentHandle,
                                          ViBoolean stateChecking);
ViStatus _VI_FUNC rsesci_setStatusRegister (ViSession instrumentHandle,
                                            ViInt32 registerOperation,
                                            ViInt32 questionableRegister,
                                            ViInt32 enable, ViInt32 PTransition,
                                            ViInt32 NTransition);
ViStatus _VI_FUNC rsesci_getStatusRegister (ViSession instrumentHandle,
                                            ViInt32 statusRegistersQuery,
                                            ViInt32* registerValue);
ViStatus _VI_FUNC rsesci_writeInstrData (ViSession instrumentHandle,
                                         ViString writeBuffer);
ViStatus _VI_FUNC rsesci_readInstrData (ViSession instrumentHandle,
                                        ViInt32 numberBytesToRead,
                                        ViChar _VI_FAR readBuffer[],
                                        ViInt32* numBytesRead);
ViStatus _VI_FUNC rsesci_reset (ViSession instrumentHandle);
ViStatus _VI_FUNC rsesci_self_test (ViSession instrumentHandle,
                                    ViInt16* selfTestResult,
                                    ViChar _VI_FAR selfTestMessage[]);
ViStatus _VI_FUNC rsesci_error_query (ViSession instrumentHandle,
                                      ViInt32* errorCode,
                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC rsesci_error_message (ViSession instrumentHandle,
                                        ViStatus statusCode,
                                        ViChar _VI_FAR message[]);
ViStatus _VI_FUNC rsesci_revision_query (ViSession instrumentHandle,
                                         ViChar _VI_FAR instrumentDriverRevision[],
                                         ViChar _VI_FAR firmwareRevision[]);
ViStatus _VI_FUNC rsesci_close (ViSession instrumentHandle);



#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif

/*****************************************************************************/
/*=== END INCLUDE FILE ======================================================*/
/*****************************************************************************/

#endif
